
#pragma once


#include <glbinding/nogl.h>

#include <glbinding/gl33core/types.h>
#include <glbinding/gl33core/values.h>
#include <glbinding/gl33core/boolean.h>
#include <glbinding/gl33core/bitfield.h>
#include <glbinding/gl33core/enum.h>
#include <glbinding/gl33core/functions.h>

#include <glbinding/gl/extension.h>