
#pragma once


#include <glbinding/nogl.h>

#include <glbinding/gl/values.h>


namespace gl12ext
{


// import values to namespace
using gl::GL_ALL_PIXELS_AMD;
using gl::GL_INVALID_INDEX;
using gl::GL_LUID_SIZE_EXT;
using gl::GL_TIMEOUT_IGNORED;
using gl::GL_UUID_SIZE_EXT;


} // namespace gl12ext