
#pragma once


#include <glbinding/nogl.h>
#include <glbinding/gl/types.h>


namespace gl45ext
{



using gl::_cl_context;
using gl::_cl_event;
using gl::AttribMask;
using gl::BufferStorageMask;
using gl::ClearBufferMask;
using gl::ClientAttribMask;
using gl::ContextFlagMask;
using gl::ContextProfileMask;
using gl::FfdMaskSGIX;
using gl::FragmentShaderColorModMaskATI;
using gl::FragmentShaderDestMaskATI;
using gl::FragmentShaderDestModMaskATI;
using gl::GLbitfield;
using gl::GLboolean;
using gl::GLbyte;
using gl::GLchar;
using gl::GLcharARB;
using gl::GLclampd;
using gl::GLclampf;
using gl::GLclampx;
using gl::GLDEBUGPROC;
using gl::GLDEBUGPROCAMD;
using gl::GLDEBUGPROCARB;
using gl::GLDEBUGPROCKHR;
using gl::GLdouble;
using gl::GLeglClientBufferEXT;
using gl::GLeglImageOES;
using gl::GLenum;
using gl::GLextension;
using gl::GLfixed;
using gl::GLfloat;
using gl::GLhalf;
using gl::GLhalfARB;
using gl::GLhalfNV;
using gl::GLhandleARB;
using gl::GLint;
using gl::GLint64;
using gl::GLint64EXT;
using gl::GLintptr;
using gl::GLintptrARB;
using gl::GLshort;
using gl::GLsizei;
using gl::GLsizeiptr;
using gl::GLsizeiptrARB;
using gl::GLsync;
using gl::GLubyte;
using gl::GLuint;
using gl::GLuint64;
using gl::GLuint64EXT;
using gl::GLushort;
using gl::GLvdpauSurfaceNV;
using gl::GLvoid;
using gl::GLVULKANPROCNV;
using gl::MapBufferAccessMask;
using gl::MemoryBarrierMask;
using gl::OcclusionQueryEventMaskAMD;
using gl::PathFontStyle;
using gl::PathMetricMask;
using gl::PerformanceQueryCapsMaskINTEL;
using gl::SyncObjectMask;
using gl::TextureStorageMaskAMD;
using gl::UnusedMask;
using gl::UseProgramStageMask;
using gl::VertexHintsMaskPGI;
using gl::VertexShaderWriteMaskEXT;


} // namespace gl45ext