
#pragma once


#include <glbinding/nogl.h>

#include <glbinding/gl/bitfield.h>


namespace gl21
{


// import bitfields to namespace
using gl::GL_ACCUM_BUFFER_BIT;
using gl::GL_ALL_ATTRIB_BITS;
using gl::GL_CLIENT_ALL_ATTRIB_BITS;
using gl::GL_CLIENT_PIXEL_STORE_BIT;
using gl::GL_CLIENT_VERTEX_ARRAY_BIT;
using gl::GL_COLOR_BUFFER_BIT;
using gl::GL_CURRENT_BIT;
using gl::GL_DEPTH_BUFFER_BIT;
using gl::GL_ENABLE_BIT;
using gl::GL_EVAL_BIT;
using gl::GL_FOG_BIT;
using gl::GL_HINT_BIT;
using gl::GL_LIGHTING_BIT;
using gl::GL_LINE_BIT;
using gl::GL_LIST_BIT;
using gl::GL_MULTISAMPLE_BIT;
using gl::GL_PIXEL_MODE_BIT;
using gl::GL_POINT_BIT;
using gl::GL_POLYGON_BIT;
using gl::GL_POLYGON_STIPPLE_BIT;
using gl::GL_SCISSOR_BIT;
using gl::GL_STENCIL_BUFFER_BIT;
using gl::GL_TEXTURE_BIT;
using gl::GL_TRANSFORM_BIT;
using gl::GL_VIEWPORT_BIT;


} // namespace gl21