
#pragma once


#include <glbinding/nogl.h>

#include <glbinding/gl/boolean.h>


namespace gl42
{


// use boolean type
using gl::GLboolean;


// import booleans to namespace
using gl::GL_FALSE;
using gl::GL_TRUE;


} // namespace gl42