
#pragma once


#include <glbinding/nogl.h>

#include <glbinding/gl33/types.h>
#include <glbinding/gl33/values.h>
#include <glbinding/gl33/boolean.h>
#include <glbinding/gl33/bitfield.h>
#include <glbinding/gl33/enum.h>
#include <glbinding/gl33/functions.h>

#include <glbinding/gl/extension.h>