
#define GLBINDING_PROJECT_NAME        "glbinding"
#define GLBINDING_PROJECT_DESCRIPTION "A C++ binding for the OpenGL API, generated using the gl.xml specification."

#define GLBINDING_AUTHOR_ORGANIZATION "CG Internals GmbH"
#define GLBINDING_AUTHOR_DOMAIN       "https://github.com/cginternals/glbinding/"
#define GLBINDING_AUTHOR_MAINTAINER   "opensource@cginternals.com"

#define GLBINDING_VERSION_MAJOR       "3"
#define GLBINDING_VERSION_MINOR       "5"
#define GLBINDING_VERSION_PATCH       "0"
#define GLBINDING_VERSION_REVISION    "0"

#define GLBINDING_VERSION             "3.5.0"
#define GLBINDING_NAME_VERSION        "glbinding v3.5.0 (0)"
