
#pragma once


#include <glbinding/glbinding_features.h>

#include <glbinding/nogl.h>
#include <glbinding/gl/types.h>


namespace gl
{


GLBINDING_CONSTEXPR static const GLuint GL_ALL_PIXELS_AMD = 0xFFFFFFFF;
GLBINDING_CONSTEXPR static const GLuint GL_INVALID_INDEX = 0xFFFFFFFF;
GLBINDING_CONSTEXPR static const GLuint GL_LUID_SIZE_EXT = 8;
GLBINDING_CONSTEXPR static const GLuint64 GL_TIMEOUT_IGNORED = 0xFFFFFFFFFFFFFFFF;
GLBINDING_CONSTEXPR static const GLuint64 GL_TIMEOUT_IGNORED_APPLE = 0xFFFFFFFFFFFFFFFF;
GLBINDING_CONSTEXPR static const GLuint GL_UUID_SIZE_EXT = 16;


} // namespace gl