
#pragma once


#include <glbinding/nogl.h>

#include <glbinding/gl21/types.h>
#include <glbinding/gl21/values.h>
#include <glbinding/gl21/boolean.h>
#include <glbinding/gl21/bitfield.h>
#include <glbinding/gl21/enum.h>
#include <glbinding/gl21/functions.h>

#include <glbinding/gl/extension.h>