
#pragma once


#include <glbinding/nogl.h>

#include <glbinding/gl41/types.h>
#include <glbinding/gl41/values.h>
#include <glbinding/gl41/boolean.h>
#include <glbinding/gl41/bitfield.h>
#include <glbinding/gl41/enum.h>
#include <glbinding/gl41/functions.h>

#include <glbinding/gl/extension.h>