
#pragma once


#include <glbinding/nogl.h>
#include <glbinding/gl/functions.h>


namespace gl15ext
{

// import functions
using gl::glAccumxOES;
using gl::glAcquireKeyedMutexWin32EXT;
using gl::glActiveProgramEXT;
using gl::glActiveShaderProgram;
using gl::glActiveShaderProgramEXT;
using gl::glActiveStencilFaceEXT;
using gl::glActiveTextureARB;
using gl::glActiveVaryingNV;
using gl::glAlphaFragmentOp1ATI;
using gl::glAlphaFragmentOp2ATI;
using gl::glAlphaFragmentOp3ATI;
using gl::glAlphaFuncxOES;
using gl::glAlphaToCoverageDitherControlNV;
using gl::glApplyFramebufferAttachmentCMAAINTEL;
using gl::glApplyTextureEXT;
using gl::glAreProgramsResidentNV;
using gl::glAreTexturesResidentEXT;
using gl::glArrayElementEXT;
using gl::glArrayObjectATI;
using gl::glAsyncCopyBufferSubDataNVX;
using gl::glAsyncCopyImageSubDataNVX;
using gl::glAsyncMarkerSGIX;
using gl::glAttachObjectARB;
using gl::glAttachShader;
using gl::glBeginConditionalRender;
using gl::glBeginConditionalRenderNV;
using gl::glBeginConditionalRenderNVX;
using gl::glBeginFragmentShaderATI;
using gl::glBeginOcclusionQueryNV;
using gl::glBeginPerfMonitorAMD;
using gl::glBeginPerfQueryINTEL;
using gl::glBeginQueryARB;
using gl::glBeginQueryIndexed;
using gl::glBeginTransformFeedback;
using gl::glBeginTransformFeedbackEXT;
using gl::glBeginTransformFeedbackNV;
using gl::glBeginVertexShaderEXT;
using gl::glBeginVideoCaptureNV;
using gl::glBindAttribLocation;
using gl::glBindAttribLocationARB;
using gl::glBindBufferARB;
using gl::glBindBufferBase;
using gl::glBindBufferBaseEXT;
using gl::glBindBufferBaseNV;
using gl::glBindBufferOffsetEXT;
using gl::glBindBufferOffsetNV;
using gl::glBindBufferRange;
using gl::glBindBufferRangeEXT;
using gl::glBindBufferRangeNV;
using gl::glBindBuffersBase;
using gl::glBindBuffersRange;
using gl::glBindFragDataLocation;
using gl::glBindFragDataLocationEXT;
using gl::glBindFragDataLocationIndexed;
using gl::glBindFragmentShaderATI;
using gl::glBindFramebuffer;
using gl::glBindFramebufferEXT;
using gl::glBindImageTexture;
using gl::glBindImageTextureEXT;
using gl::glBindImageTextures;
using gl::glBindLightParameterEXT;
using gl::glBindMaterialParameterEXT;
using gl::glBindMultiTextureEXT;
using gl::glBindParameterEXT;
using gl::glBindProgramARB;
using gl::glBindProgramNV;
using gl::glBindProgramPipeline;
using gl::glBindProgramPipelineEXT;
using gl::glBindRenderbuffer;
using gl::glBindRenderbufferEXT;
using gl::glBindSampler;
using gl::glBindSamplers;
using gl::glBindShadingRateImageNV;
using gl::glBindTexGenParameterEXT;
using gl::glBindTextureEXT;
using gl::glBindTextures;
using gl::glBindTextureUnit;
using gl::glBindTextureUnitParameterEXT;
using gl::glBindTransformFeedback;
using gl::glBindTransformFeedbackNV;
using gl::glBindVertexArray;
using gl::glBindVertexArrayAPPLE;
using gl::glBindVertexBuffer;
using gl::glBindVertexBuffers;
using gl::glBindVertexShaderEXT;
using gl::glBindVideoCaptureStreamBufferNV;
using gl::glBindVideoCaptureStreamTextureNV;
using gl::glBinormal3bEXT;
using gl::glBinormal3bvEXT;
using gl::glBinormal3dEXT;
using gl::glBinormal3dvEXT;
using gl::glBinormal3fEXT;
using gl::glBinormal3fvEXT;
using gl::glBinormal3iEXT;
using gl::glBinormal3ivEXT;
using gl::glBinormal3sEXT;
using gl::glBinormal3svEXT;
using gl::glBinormalPointerEXT;
using gl::glBitmapxOES;
using gl::glBlendBarrierKHR;
using gl::glBlendBarrierNV;
using gl::glBlendColorEXT;
using gl::glBlendColorxOES;
using gl::glBlendEquationEXT;
using gl::glBlendEquationi;
using gl::glBlendEquationiARB;
using gl::glBlendEquationIndexedAMD;
using gl::glBlendEquationSeparate;
using gl::glBlendEquationSeparateEXT;
using gl::glBlendEquationSeparatei;
using gl::glBlendEquationSeparateiARB;
using gl::glBlendEquationSeparateIndexedAMD;
using gl::glBlendFunci;
using gl::glBlendFunciARB;
using gl::glBlendFuncIndexedAMD;
using gl::glBlendFuncSeparateEXT;
using gl::glBlendFuncSeparatei;
using gl::glBlendFuncSeparateiARB;
using gl::glBlendFuncSeparateIndexedAMD;
using gl::glBlendFuncSeparateINGR;
using gl::glBlendParameteriNV;
using gl::glBlitFramebuffer;
using gl::glBlitFramebufferEXT;
using gl::glBlitFramebufferLayerEXT;
using gl::glBlitFramebufferLayersEXT;
using gl::glBlitNamedFramebuffer;
using gl::glBufferAddressRangeNV;
using gl::glBufferAttachMemoryNV;
using gl::glBufferDataARB;
using gl::glBufferPageCommitmentARB;
using gl::glBufferPageCommitmentMemNV;
using gl::glBufferParameteriAPPLE;
using gl::glBufferStorage;
using gl::glBufferStorageExternalEXT;
using gl::glBufferStorageMemEXT;
using gl::glBufferSubDataARB;
using gl::glCallCommandListNV;
using gl::glCheckFramebufferStatus;
using gl::glCheckFramebufferStatusEXT;
using gl::glCheckNamedFramebufferStatus;
using gl::glCheckNamedFramebufferStatusEXT;
using gl::glClampColor;
using gl::glClampColorARB;
using gl::glClearAccumxOES;
using gl::glClearBufferData;
using gl::glClearBufferfi;
using gl::glClearBufferfv;
using gl::glClearBufferiv;
using gl::glClearBufferSubData;
using gl::glClearBufferuiv;
using gl::glClearColorIiEXT;
using gl::glClearColorIuiEXT;
using gl::glClearColorxOES;
using gl::glClearDepthdNV;
using gl::glClearDepthf;
using gl::glClearDepthfOES;
using gl::glClearDepthxOES;
using gl::glClearNamedBufferData;
using gl::glClearNamedBufferDataEXT;
using gl::glClearNamedBufferSubData;
using gl::glClearNamedBufferSubDataEXT;
using gl::glClearNamedFramebufferfi;
using gl::glClearNamedFramebufferfv;
using gl::glClearNamedFramebufferiv;
using gl::glClearNamedFramebufferuiv;
using gl::glClearTexImage;
using gl::glClearTexSubImage;
using gl::glClientActiveTextureARB;
using gl::glClientActiveVertexStreamATI;
using gl::glClientAttribDefaultEXT;
using gl::glClientWaitSemaphoreui64NVX;
using gl::glClientWaitSync;
using gl::glClipControl;
using gl::glClipPlanefOES;
using gl::glClipPlanexOES;
using gl::glColor3fVertex3fSUN;
using gl::glColor3fVertex3fvSUN;
using gl::glColor3hNV;
using gl::glColor3hvNV;
using gl::glColor3xOES;
using gl::glColor3xvOES;
using gl::glColor4fNormal3fVertex3fSUN;
using gl::glColor4fNormal3fVertex3fvSUN;
using gl::glColor4hNV;
using gl::glColor4hvNV;
using gl::glColor4ubVertex2fSUN;
using gl::glColor4ubVertex2fvSUN;
using gl::glColor4ubVertex3fSUN;
using gl::glColor4ubVertex3fvSUN;
using gl::glColor4xOES;
using gl::glColor4xvOES;
using gl::glColorFormatNV;
using gl::glColorFragmentOp1ATI;
using gl::glColorFragmentOp2ATI;
using gl::glColorFragmentOp3ATI;
using gl::glColorMaski;
using gl::glColorMaskIndexedEXT;
using gl::glColorP3ui;
using gl::glColorP3uiv;
using gl::glColorP4ui;
using gl::glColorP4uiv;
using gl::glColorPointerEXT;
using gl::glColorPointerListIBM;
using gl::glColorPointervINTEL;
using gl::glColorSubTable;
using gl::glColorSubTableEXT;
using gl::glColorTable;
using gl::glColorTableEXT;
using gl::glColorTableParameterfv;
using gl::glColorTableParameterfvSGI;
using gl::glColorTableParameteriv;
using gl::glColorTableParameterivSGI;
using gl::glColorTableSGI;
using gl::glCombinerInputNV;
using gl::glCombinerOutputNV;
using gl::glCombinerParameterfNV;
using gl::glCombinerParameterfvNV;
using gl::glCombinerParameteriNV;
using gl::glCombinerParameterivNV;
using gl::glCombinerStageParameterfvNV;
using gl::glCommandListSegmentsNV;
using gl::glCompileCommandListNV;
using gl::glCompileShader;
using gl::glCompileShaderARB;
using gl::glCompileShaderIncludeARB;
using gl::glCompressedMultiTexImage1DEXT;
using gl::glCompressedMultiTexImage2DEXT;
using gl::glCompressedMultiTexImage3DEXT;
using gl::glCompressedMultiTexSubImage1DEXT;
using gl::glCompressedMultiTexSubImage2DEXT;
using gl::glCompressedMultiTexSubImage3DEXT;
using gl::glCompressedTexImage1DARB;
using gl::glCompressedTexImage2DARB;
using gl::glCompressedTexImage3DARB;
using gl::glCompressedTexSubImage1DARB;
using gl::glCompressedTexSubImage2DARB;
using gl::glCompressedTexSubImage3DARB;
using gl::glCompressedTextureImage1DEXT;
using gl::glCompressedTextureImage2DEXT;
using gl::glCompressedTextureImage3DEXT;
using gl::glCompressedTextureSubImage1D;
using gl::glCompressedTextureSubImage1DEXT;
using gl::glCompressedTextureSubImage2D;
using gl::glCompressedTextureSubImage2DEXT;
using gl::glCompressedTextureSubImage3D;
using gl::glCompressedTextureSubImage3DEXT;
using gl::glConservativeRasterParameterfNV;
using gl::glConservativeRasterParameteriNV;
using gl::glConvolutionFilter1D;
using gl::glConvolutionFilter1DEXT;
using gl::glConvolutionFilter2D;
using gl::glConvolutionFilter2DEXT;
using gl::glConvolutionParameterf;
using gl::glConvolutionParameterfEXT;
using gl::glConvolutionParameterfv;
using gl::glConvolutionParameterfvEXT;
using gl::glConvolutionParameteri;
using gl::glConvolutionParameteriEXT;
using gl::glConvolutionParameteriv;
using gl::glConvolutionParameterivEXT;
using gl::glConvolutionParameterxOES;
using gl::glConvolutionParameterxvOES;
using gl::glCopyBufferSubData;
using gl::glCopyColorSubTable;
using gl::glCopyColorSubTableEXT;
using gl::glCopyColorTable;
using gl::glCopyColorTableSGI;
using gl::glCopyConvolutionFilter1D;
using gl::glCopyConvolutionFilter1DEXT;
using gl::glCopyConvolutionFilter2D;
using gl::glCopyConvolutionFilter2DEXT;
using gl::glCopyImageSubData;
using gl::glCopyImageSubDataNV;
using gl::glCopyMultiTexImage1DEXT;
using gl::glCopyMultiTexImage2DEXT;
using gl::glCopyMultiTexSubImage1DEXT;
using gl::glCopyMultiTexSubImage2DEXT;
using gl::glCopyMultiTexSubImage3DEXT;
using gl::glCopyNamedBufferSubData;
using gl::glCopyPathNV;
using gl::glCopyTexImage1DEXT;
using gl::glCopyTexImage2DEXT;
using gl::glCopyTexSubImage1DEXT;
using gl::glCopyTexSubImage2DEXT;
using gl::glCopyTexSubImage3DEXT;
using gl::glCopyTextureImage1DEXT;
using gl::glCopyTextureImage2DEXT;
using gl::glCopyTextureSubImage1D;
using gl::glCopyTextureSubImage1DEXT;
using gl::glCopyTextureSubImage2D;
using gl::glCopyTextureSubImage2DEXT;
using gl::glCopyTextureSubImage3D;
using gl::glCopyTextureSubImage3DEXT;
using gl::glCoverageModulationNV;
using gl::glCoverageModulationTableNV;
using gl::glCoverFillPathInstancedNV;
using gl::glCoverFillPathNV;
using gl::glCoverStrokePathInstancedNV;
using gl::glCoverStrokePathNV;
using gl::glCreateBuffers;
using gl::glCreateCommandListsNV;
using gl::glCreateFramebuffers;
using gl::glCreateMemoryObjectsEXT;
using gl::glCreatePerfQueryINTEL;
using gl::glCreateProgram;
using gl::glCreateProgramObjectARB;
using gl::glCreateProgramPipelines;
using gl::glCreateProgressFenceNVX;
using gl::glCreateQueries;
using gl::glCreateRenderbuffers;
using gl::glCreateSamplers;
using gl::glCreateSemaphoresNV;
using gl::glCreateShader;
using gl::glCreateShaderObjectARB;
using gl::glCreateShaderProgramEXT;
using gl::glCreateShaderProgramv;
using gl::glCreateShaderProgramvEXT;
using gl::glCreateStatesNV;
using gl::glCreateSyncFromCLeventARB;
using gl::glCreateTextures;
using gl::glCreateTransformFeedbacks;
using gl::glCreateVertexArrays;
using gl::glCullParameterdvEXT;
using gl::glCullParameterfvEXT;
using gl::glCurrentPaletteMatrixARB;
using gl::glDebugMessageCallback;
using gl::glDebugMessageCallbackAMD;
using gl::glDebugMessageCallbackARB;
using gl::glDebugMessageCallbackKHR;
using gl::glDebugMessageControl;
using gl::glDebugMessageControlARB;
using gl::glDebugMessageControlKHR;
using gl::glDebugMessageEnableAMD;
using gl::glDebugMessageInsert;
using gl::glDebugMessageInsertAMD;
using gl::glDebugMessageInsertARB;
using gl::glDebugMessageInsertKHR;
using gl::glDeformationMap3dSGIX;
using gl::glDeformationMap3fSGIX;
using gl::glDeformSGIX;
using gl::glDeleteAsyncMarkersSGIX;
using gl::glDeleteBuffersARB;
using gl::glDeleteCommandListsNV;
using gl::glDeleteFencesAPPLE;
using gl::glDeleteFencesNV;
using gl::glDeleteFragmentShaderATI;
using gl::glDeleteFramebuffers;
using gl::glDeleteFramebuffersEXT;
using gl::glDeleteMemoryObjectsEXT;
using gl::glDeleteNamedStringARB;
using gl::glDeleteNamesAMD;
using gl::glDeleteObjectARB;
using gl::glDeleteOcclusionQueriesNV;
using gl::glDeletePathsNV;
using gl::glDeletePerfMonitorsAMD;
using gl::glDeletePerfQueryINTEL;
using gl::glDeleteProgram;
using gl::glDeleteProgramPipelines;
using gl::glDeleteProgramPipelinesEXT;
using gl::glDeleteProgramsARB;
using gl::glDeleteProgramsNV;
using gl::glDeleteQueriesARB;
using gl::glDeleteQueryResourceTagNV;
using gl::glDeleteRenderbuffers;
using gl::glDeleteRenderbuffersEXT;
using gl::glDeleteSamplers;
using gl::glDeleteSemaphoresEXT;
using gl::glDeleteShader;
using gl::glDeleteStatesNV;
using gl::glDeleteSync;
using gl::glDeleteTexturesEXT;
using gl::glDeleteTransformFeedbacks;
using gl::glDeleteTransformFeedbacksNV;
using gl::glDeleteVertexArrays;
using gl::glDeleteVertexArraysAPPLE;
using gl::glDeleteVertexShaderEXT;
using gl::glDepthBoundsdNV;
using gl::glDepthBoundsEXT;
using gl::glDepthRangeArraydvNV;
using gl::glDepthRangeArrayv;
using gl::glDepthRangedNV;
using gl::glDepthRangef;
using gl::glDepthRangefOES;
using gl::glDepthRangeIndexed;
using gl::glDepthRangeIndexeddNV;
using gl::glDepthRangexOES;
using gl::glDetachObjectARB;
using gl::glDetachShader;
using gl::glDetailTexFuncSGIS;
using gl::glDisableClientStateiEXT;
using gl::glDisableClientStateIndexedEXT;
using gl::glDisablei;
using gl::glDisableIndexedEXT;
using gl::glDisableVariantClientStateEXT;
using gl::glDisableVertexArrayAttrib;
using gl::glDisableVertexArrayAttribEXT;
using gl::glDisableVertexArrayEXT;
using gl::glDisableVertexAttribAPPLE;
using gl::glDisableVertexAttribArray;
using gl::glDisableVertexAttribArrayARB;
using gl::glDispatchCompute;
using gl::glDispatchComputeGroupSizeARB;
using gl::glDispatchComputeIndirect;
using gl::glDrawArraysEXT;
using gl::glDrawArraysIndirect;
using gl::glDrawArraysInstanced;
using gl::glDrawArraysInstancedARB;
using gl::glDrawArraysInstancedBaseInstance;
using gl::glDrawArraysInstancedEXT;
using gl::glDrawBuffers;
using gl::glDrawBuffersARB;
using gl::glDrawBuffersATI;
using gl::glDrawCommandsAddressNV;
using gl::glDrawCommandsNV;
using gl::glDrawCommandsStatesAddressNV;
using gl::glDrawCommandsStatesNV;
using gl::glDrawElementArrayAPPLE;
using gl::glDrawElementArrayATI;
using gl::glDrawElementsBaseVertex;
using gl::glDrawElementsIndirect;
using gl::glDrawElementsInstanced;
using gl::glDrawElementsInstancedARB;
using gl::glDrawElementsInstancedBaseInstance;
using gl::glDrawElementsInstancedBaseVertex;
using gl::glDrawElementsInstancedBaseVertexBaseInstance;
using gl::glDrawElementsInstancedEXT;
using gl::glDrawMeshArraysSUN;
using gl::glDrawMeshTasksIndirectNV;
using gl::glDrawMeshTasksNV;
using gl::glDrawRangeElementArrayAPPLE;
using gl::glDrawRangeElementArrayATI;
using gl::glDrawRangeElementsBaseVertex;
using gl::glDrawRangeElementsEXT;
using gl::glDrawTextureNV;
using gl::glDrawTransformFeedback;
using gl::glDrawTransformFeedbackInstanced;
using gl::glDrawTransformFeedbackNV;
using gl::glDrawTransformFeedbackStream;
using gl::glDrawTransformFeedbackStreamInstanced;
using gl::glDrawVkImageNV;
using gl::glEdgeFlagFormatNV;
using gl::glEdgeFlagPointerEXT;
using gl::glEdgeFlagPointerListIBM;
using gl::glEGLImageTargetTexStorageEXT;
using gl::glEGLImageTargetTextureStorageEXT;
using gl::glElementPointerAPPLE;
using gl::glElementPointerATI;
using gl::glEnableClientStateiEXT;
using gl::glEnableClientStateIndexedEXT;
using gl::glEnablei;
using gl::glEnableIndexedEXT;
using gl::glEnableVariantClientStateEXT;
using gl::glEnableVertexArrayAttrib;
using gl::glEnableVertexArrayAttribEXT;
using gl::glEnableVertexArrayEXT;
using gl::glEnableVertexAttribAPPLE;
using gl::glEnableVertexAttribArray;
using gl::glEnableVertexAttribArrayARB;
using gl::glEndConditionalRender;
using gl::glEndConditionalRenderNV;
using gl::glEndConditionalRenderNVX;
using gl::glEndFragmentShaderATI;
using gl::glEndOcclusionQueryNV;
using gl::glEndPerfMonitorAMD;
using gl::glEndPerfQueryINTEL;
using gl::glEndQueryARB;
using gl::glEndQueryIndexed;
using gl::glEndTransformFeedback;
using gl::glEndTransformFeedbackEXT;
using gl::glEndTransformFeedbackNV;
using gl::glEndVertexShaderEXT;
using gl::glEndVideoCaptureNV;
using gl::glEvalCoord1xOES;
using gl::glEvalCoord1xvOES;
using gl::glEvalCoord2xOES;
using gl::glEvalCoord2xvOES;
using gl::glEvalMapsNV;
using gl::glEvaluateDepthValuesARB;
using gl::glExecuteProgramNV;
using gl::glExtractComponentEXT;
using gl::glFeedbackBufferxOES;
using gl::glFenceSync;
using gl::glFinalCombinerInputNV;
using gl::glFinishAsyncSGIX;
using gl::glFinishFenceAPPLE;
using gl::glFinishFenceNV;
using gl::glFinishObjectAPPLE;
using gl::glFinishTextureSUNX;
using gl::glFlushMappedBufferRange;
using gl::glFlushMappedBufferRangeAPPLE;
using gl::glFlushMappedNamedBufferRange;
using gl::glFlushMappedNamedBufferRangeEXT;
using gl::glFlushPixelDataRangeNV;
using gl::glFlushRasterSGIX;
using gl::glFlushStaticDataIBM;
using gl::glFlushVertexArrayRangeAPPLE;
using gl::glFlushVertexArrayRangeNV;
using gl::glFogCoorddEXT;
using gl::glFogCoorddvEXT;
using gl::glFogCoordfEXT;
using gl::glFogCoordFormatNV;
using gl::glFogCoordfvEXT;
using gl::glFogCoordhNV;
using gl::glFogCoordhvNV;
using gl::glFogCoordPointerEXT;
using gl::glFogCoordPointerListIBM;
using gl::glFogFuncSGIS;
using gl::glFogxOES;
using gl::glFogxvOES;
using gl::glFragmentColorMaterialSGIX;
using gl::glFragmentCoverageColorNV;
using gl::glFragmentLightfSGIX;
using gl::glFragmentLightfvSGIX;
using gl::glFragmentLightiSGIX;
using gl::glFragmentLightivSGIX;
using gl::glFragmentLightModelfSGIX;
using gl::glFragmentLightModelfvSGIX;
using gl::glFragmentLightModeliSGIX;
using gl::glFragmentLightModelivSGIX;
using gl::glFragmentMaterialfSGIX;
using gl::glFragmentMaterialfvSGIX;
using gl::glFragmentMaterialiSGIX;
using gl::glFragmentMaterialivSGIX;
using gl::glFramebufferDrawBufferEXT;
using gl::glFramebufferDrawBuffersEXT;
using gl::glFramebufferFetchBarrierEXT;
using gl::glFramebufferParameteri;
using gl::glFramebufferParameteriMESA;
using gl::glFramebufferReadBufferEXT;
using gl::glFramebufferRenderbuffer;
using gl::glFramebufferRenderbufferEXT;
using gl::glFramebufferSampleLocationsfvARB;
using gl::glFramebufferSampleLocationsfvNV;
using gl::glFramebufferSamplePositionsfvAMD;
using gl::glFramebufferTexture;
using gl::glFramebufferTexture1D;
using gl::glFramebufferTexture1DEXT;
using gl::glFramebufferTexture2D;
using gl::glFramebufferTexture2DEXT;
using gl::glFramebufferTexture3D;
using gl::glFramebufferTexture3DEXT;
using gl::glFramebufferTextureARB;
using gl::glFramebufferTextureEXT;
using gl::glFramebufferTextureFaceARB;
using gl::glFramebufferTextureFaceEXT;
using gl::glFramebufferTextureLayer;
using gl::glFramebufferTextureLayerARB;
using gl::glFramebufferTextureLayerEXT;
using gl::glFramebufferTextureMultiviewOVR;
using gl::glFrameTerminatorGREMEDY;
using gl::glFrameZoomSGIX;
using gl::glFreeObjectBufferATI;
using gl::glFrustumfOES;
using gl::glFrustumxOES;
using gl::glGenAsyncMarkersSGIX;
using gl::glGenBuffersARB;
using gl::glGenerateMipmap;
using gl::glGenerateMipmapEXT;
using gl::glGenerateMultiTexMipmapEXT;
using gl::glGenerateTextureMipmap;
using gl::glGenerateTextureMipmapEXT;
using gl::glGenFencesAPPLE;
using gl::glGenFencesNV;
using gl::glGenFragmentShadersATI;
using gl::glGenFramebuffers;
using gl::glGenFramebuffersEXT;
using gl::glGenNamesAMD;
using gl::glGenOcclusionQueriesNV;
using gl::glGenPathsNV;
using gl::glGenPerfMonitorsAMD;
using gl::glGenProgramPipelines;
using gl::glGenProgramPipelinesEXT;
using gl::glGenProgramsARB;
using gl::glGenProgramsNV;
using gl::glGenQueriesARB;
using gl::glGenQueryResourceTagNV;
using gl::glGenRenderbuffers;
using gl::glGenRenderbuffersEXT;
using gl::glGenSamplers;
using gl::glGenSemaphoresEXT;
using gl::glGenSymbolsEXT;
using gl::glGenTexturesEXT;
using gl::glGenTransformFeedbacks;
using gl::glGenTransformFeedbacksNV;
using gl::glGenVertexArrays;
using gl::glGenVertexArraysAPPLE;
using gl::glGenVertexShadersEXT;
using gl::glGetActiveAtomicCounterBufferiv;
using gl::glGetActiveAttrib;
using gl::glGetActiveAttribARB;
using gl::glGetActiveSubroutineName;
using gl::glGetActiveSubroutineUniformiv;
using gl::glGetActiveSubroutineUniformName;
using gl::glGetActiveUniform;
using gl::glGetActiveUniformARB;
using gl::glGetActiveUniformBlockiv;
using gl::glGetActiveUniformBlockName;
using gl::glGetActiveUniformName;
using gl::glGetActiveUniformsiv;
using gl::glGetActiveVaryingNV;
using gl::glGetArrayObjectfvATI;
using gl::glGetArrayObjectivATI;
using gl::glGetAttachedObjectsARB;
using gl::glGetAttachedShaders;
using gl::glGetAttribLocation;
using gl::glGetAttribLocationARB;
using gl::glGetBooleani_v;
using gl::glGetBooleanIndexedvEXT;
using gl::glGetBufferParameteri64v;
using gl::glGetBufferParameterivARB;
using gl::glGetBufferParameterui64vNV;
using gl::glGetBufferPointervARB;
using gl::glGetBufferSubDataARB;
using gl::glGetClipPlanefOES;
using gl::glGetClipPlanexOES;
using gl::glGetColorTable;
using gl::glGetColorTableEXT;
using gl::glGetColorTableParameterfv;
using gl::glGetColorTableParameterfvEXT;
using gl::glGetColorTableParameterfvSGI;
using gl::glGetColorTableParameteriv;
using gl::glGetColorTableParameterivEXT;
using gl::glGetColorTableParameterivSGI;
using gl::glGetColorTableSGI;
using gl::glGetCombinerInputParameterfvNV;
using gl::glGetCombinerInputParameterivNV;
using gl::glGetCombinerOutputParameterfvNV;
using gl::glGetCombinerOutputParameterivNV;
using gl::glGetCombinerStageParameterfvNV;
using gl::glGetCommandHeaderNV;
using gl::glGetCompressedMultiTexImageEXT;
using gl::glGetCompressedTexImageARB;
using gl::glGetCompressedTextureImage;
using gl::glGetCompressedTextureImageEXT;
using gl::glGetCompressedTextureSubImage;
using gl::glGetConvolutionFilter;
using gl::glGetConvolutionFilterEXT;
using gl::glGetConvolutionParameterfv;
using gl::glGetConvolutionParameterfvEXT;
using gl::glGetConvolutionParameteriv;
using gl::glGetConvolutionParameterivEXT;
using gl::glGetConvolutionParameterxvOES;
using gl::glGetCoverageModulationTableNV;
using gl::glGetDebugMessageLog;
using gl::glGetDebugMessageLogAMD;
using gl::glGetDebugMessageLogARB;
using gl::glGetDebugMessageLogKHR;
using gl::glGetDetailTexFuncSGIS;
using gl::glGetDoublei_v;
using gl::glGetDoublei_vEXT;
using gl::glGetDoubleIndexedvEXT;
using gl::glGetFenceivNV;
using gl::glGetFinalCombinerInputParameterfvNV;
using gl::glGetFinalCombinerInputParameterivNV;
using gl::glGetFirstPerfQueryIdINTEL;
using gl::glGetFixedvOES;
using gl::glGetFloati_v;
using gl::glGetFloati_vEXT;
using gl::glGetFloatIndexedvEXT;
using gl::glGetFogFuncSGIS;
using gl::glGetFragDataIndex;
using gl::glGetFragDataLocation;
using gl::glGetFragDataLocationEXT;
using gl::glGetFragmentLightfvSGIX;
using gl::glGetFragmentLightivSGIX;
using gl::glGetFragmentMaterialfvSGIX;
using gl::glGetFragmentMaterialivSGIX;
using gl::glGetFramebufferAttachmentParameteriv;
using gl::glGetFramebufferAttachmentParameterivEXT;
using gl::glGetFramebufferParameterfvAMD;
using gl::glGetFramebufferParameteriv;
using gl::glGetFramebufferParameterivEXT;
using gl::glGetFramebufferParameterivMESA;
using gl::glGetGraphicsResetStatus;
using gl::glGetGraphicsResetStatusARB;
using gl::glGetGraphicsResetStatusKHR;
using gl::glGetHandleARB;
using gl::glGetHistogram;
using gl::glGetHistogramEXT;
using gl::glGetHistogramParameterfv;
using gl::glGetHistogramParameterfvEXT;
using gl::glGetHistogramParameteriv;
using gl::glGetHistogramParameterivEXT;
using gl::glGetHistogramParameterxvOES;
using gl::glGetImageHandleARB;
using gl::glGetImageHandleNV;
using gl::glGetImageTransformParameterfvHP;
using gl::glGetImageTransformParameterivHP;
using gl::glGetInfoLogARB;
using gl::glGetInstrumentsSGIX;
using gl::glGetInteger64i_v;
using gl::glGetInteger64v;
using gl::glGetIntegeri_v;
using gl::glGetIntegerIndexedvEXT;
using gl::glGetIntegerui64i_vNV;
using gl::glGetIntegerui64vNV;
using gl::glGetInternalformati64v;
using gl::glGetInternalformativ;
using gl::glGetInternalformatSampleivNV;
using gl::glGetInvariantBooleanvEXT;
using gl::glGetInvariantFloatvEXT;
using gl::glGetInvariantIntegervEXT;
using gl::glGetLightxOES;
using gl::glGetLightxvOES;
using gl::glGetListParameterfvSGIX;
using gl::glGetListParameterivSGIX;
using gl::glGetLocalConstantBooleanvEXT;
using gl::glGetLocalConstantFloatvEXT;
using gl::glGetLocalConstantIntegervEXT;
using gl::glGetMapAttribParameterfvNV;
using gl::glGetMapAttribParameterivNV;
using gl::glGetMapControlPointsNV;
using gl::glGetMapParameterfvNV;
using gl::glGetMapParameterivNV;
using gl::glGetMapxvOES;
using gl::glGetMaterialxOES;
using gl::glGetMaterialxvOES;
using gl::glGetMemoryObjectDetachedResourcesuivNV;
using gl::glGetMemoryObjectParameterivEXT;
using gl::glGetMinmax;
using gl::glGetMinmaxEXT;
using gl::glGetMinmaxParameterfv;
using gl::glGetMinmaxParameterfvEXT;
using gl::glGetMinmaxParameteriv;
using gl::glGetMinmaxParameterivEXT;
using gl::glGetMultisamplefv;
using gl::glGetMultisamplefvNV;
using gl::glGetMultiTexEnvfvEXT;
using gl::glGetMultiTexEnvivEXT;
using gl::glGetMultiTexGendvEXT;
using gl::glGetMultiTexGenfvEXT;
using gl::glGetMultiTexGenivEXT;
using gl::glGetMultiTexImageEXT;
using gl::glGetMultiTexLevelParameterfvEXT;
using gl::glGetMultiTexLevelParameterivEXT;
using gl::glGetMultiTexParameterfvEXT;
using gl::glGetMultiTexParameterIivEXT;
using gl::glGetMultiTexParameterIuivEXT;
using gl::glGetMultiTexParameterivEXT;
using gl::glGetNamedBufferParameteri64v;
using gl::glGetNamedBufferParameteriv;
using gl::glGetNamedBufferParameterivEXT;
using gl::glGetNamedBufferParameterui64vNV;
using gl::glGetNamedBufferPointerv;
using gl::glGetNamedBufferPointervEXT;
using gl::glGetNamedBufferSubData;
using gl::glGetNamedBufferSubDataEXT;
using gl::glGetNamedFramebufferAttachmentParameteriv;
using gl::glGetNamedFramebufferAttachmentParameterivEXT;
using gl::glGetNamedFramebufferParameterfvAMD;
using gl::glGetNamedFramebufferParameteriv;
using gl::glGetNamedFramebufferParameterivEXT;
using gl::glGetNamedProgramivEXT;
using gl::glGetNamedProgramLocalParameterdvEXT;
using gl::glGetNamedProgramLocalParameterfvEXT;
using gl::glGetNamedProgramLocalParameterIivEXT;
using gl::glGetNamedProgramLocalParameterIuivEXT;
using gl::glGetNamedProgramStringEXT;
using gl::glGetNamedRenderbufferParameteriv;
using gl::glGetNamedRenderbufferParameterivEXT;
using gl::glGetNamedStringARB;
using gl::glGetNamedStringivARB;
using gl::glGetnColorTable;
using gl::glGetnColorTableARB;
using gl::glGetnCompressedTexImage;
using gl::glGetnCompressedTexImageARB;
using gl::glGetnConvolutionFilter;
using gl::glGetnConvolutionFilterARB;
using gl::glGetNextPerfQueryIdINTEL;
using gl::glGetnHistogram;
using gl::glGetnHistogramARB;
using gl::glGetnMapdv;
using gl::glGetnMapdvARB;
using gl::glGetnMapfv;
using gl::glGetnMapfvARB;
using gl::glGetnMapiv;
using gl::glGetnMapivARB;
using gl::glGetnMinmax;
using gl::glGetnMinmaxARB;
using gl::glGetnPixelMapfv;
using gl::glGetnPixelMapfvARB;
using gl::glGetnPixelMapuiv;
using gl::glGetnPixelMapuivARB;
using gl::glGetnPixelMapusv;
using gl::glGetnPixelMapusvARB;
using gl::glGetnPolygonStipple;
using gl::glGetnPolygonStippleARB;
using gl::glGetnSeparableFilter;
using gl::glGetnSeparableFilterARB;
using gl::glGetnTexImage;
using gl::glGetnTexImageARB;
using gl::glGetnUniformdv;
using gl::glGetnUniformdvARB;
using gl::glGetnUniformfv;
using gl::glGetnUniformfvARB;
using gl::glGetnUniformfvKHR;
using gl::glGetnUniformi64vARB;
using gl::glGetnUniformiv;
using gl::glGetnUniformivARB;
using gl::glGetnUniformivKHR;
using gl::glGetnUniformui64vARB;
using gl::glGetnUniformuiv;
using gl::glGetnUniformuivARB;
using gl::glGetnUniformuivKHR;
using gl::glGetObjectBufferfvATI;
using gl::glGetObjectBufferivATI;
using gl::glGetObjectLabel;
using gl::glGetObjectLabelEXT;
using gl::glGetObjectLabelKHR;
using gl::glGetObjectParameterfvARB;
using gl::glGetObjectParameterivAPPLE;
using gl::glGetObjectParameterivARB;
using gl::glGetObjectPtrLabel;
using gl::glGetObjectPtrLabelKHR;
using gl::glGetOcclusionQueryivNV;
using gl::glGetOcclusionQueryuivNV;
using gl::glGetPathColorGenfvNV;
using gl::glGetPathColorGenivNV;
using gl::glGetPathCommandsNV;
using gl::glGetPathCoordsNV;
using gl::glGetPathDashArrayNV;
using gl::glGetPathLengthNV;
using gl::glGetPathMetricRangeNV;
using gl::glGetPathMetricsNV;
using gl::glGetPathParameterfvNV;
using gl::glGetPathParameterivNV;
using gl::glGetPathSpacingNV;
using gl::glGetPathTexGenfvNV;
using gl::glGetPathTexGenivNV;
using gl::glGetPerfCounterInfoINTEL;
using gl::glGetPerfMonitorCounterDataAMD;
using gl::glGetPerfMonitorCounterInfoAMD;
using gl::glGetPerfMonitorCountersAMD;
using gl::glGetPerfMonitorCounterStringAMD;
using gl::glGetPerfMonitorGroupsAMD;
using gl::glGetPerfMonitorGroupStringAMD;
using gl::glGetPerfQueryDataINTEL;
using gl::glGetPerfQueryIdByNameINTEL;
using gl::glGetPerfQueryInfoINTEL;
using gl::glGetPixelMapxv;
using gl::glGetPixelTexGenParameterfvSGIS;
using gl::glGetPixelTexGenParameterivSGIS;
using gl::glGetPixelTransformParameterfvEXT;
using gl::glGetPixelTransformParameterivEXT;
using gl::glGetPointeri_vEXT;
using gl::glGetPointerIndexedvEXT;
using gl::glGetPointervEXT;
using gl::glGetPointervKHR;
using gl::glGetProgramBinary;
using gl::glGetProgramEnvParameterdvARB;
using gl::glGetProgramEnvParameterfvARB;
using gl::glGetProgramEnvParameterIivNV;
using gl::glGetProgramEnvParameterIuivNV;
using gl::glGetProgramInfoLog;
using gl::glGetProgramInterfaceiv;
using gl::glGetProgramiv;
using gl::glGetProgramivARB;
using gl::glGetProgramivNV;
using gl::glGetProgramLocalParameterdvARB;
using gl::glGetProgramLocalParameterfvARB;
using gl::glGetProgramLocalParameterIivNV;
using gl::glGetProgramLocalParameterIuivNV;
using gl::glGetProgramNamedParameterdvNV;
using gl::glGetProgramNamedParameterfvNV;
using gl::glGetProgramParameterdvNV;
using gl::glGetProgramParameterfvNV;
using gl::glGetProgramPipelineInfoLog;
using gl::glGetProgramPipelineInfoLogEXT;
using gl::glGetProgramPipelineiv;
using gl::glGetProgramPipelineivEXT;
using gl::glGetProgramResourcefvNV;
using gl::glGetProgramResourceIndex;
using gl::glGetProgramResourceiv;
using gl::glGetProgramResourceLocation;
using gl::glGetProgramResourceLocationIndex;
using gl::glGetProgramResourceName;
using gl::glGetProgramStageiv;
using gl::glGetProgramStringARB;
using gl::glGetProgramStringNV;
using gl::glGetProgramSubroutineParameteruivNV;
using gl::glGetQueryBufferObjecti64v;
using gl::glGetQueryBufferObjectiv;
using gl::glGetQueryBufferObjectui64v;
using gl::glGetQueryBufferObjectuiv;
using gl::glGetQueryIndexediv;
using gl::glGetQueryivARB;
using gl::glGetQueryObjecti64v;
using gl::glGetQueryObjecti64vEXT;
using gl::glGetQueryObjectivARB;
using gl::glGetQueryObjectui64v;
using gl::glGetQueryObjectui64vEXT;
using gl::glGetQueryObjectuivARB;
using gl::glGetRenderbufferParameteriv;
using gl::glGetRenderbufferParameterivEXT;
using gl::glGetSamplerParameterfv;
using gl::glGetSamplerParameterIiv;
using gl::glGetSamplerParameterIuiv;
using gl::glGetSamplerParameteriv;
using gl::glGetSemaphoreParameterivNV;
using gl::glGetSemaphoreParameterui64vEXT;
using gl::glGetSeparableFilter;
using gl::glGetSeparableFilterEXT;
using gl::glGetShaderInfoLog;
using gl::glGetShaderiv;
using gl::glGetShaderPrecisionFormat;
using gl::glGetShaderSource;
using gl::glGetShaderSourceARB;
using gl::glGetShadingRateImagePaletteNV;
using gl::glGetShadingRateSampleLocationivNV;
using gl::glGetSharpenTexFuncSGIS;
using gl::glGetStageIndexNV;
using gl::glGetStringi;
using gl::glGetSubroutineIndex;
using gl::glGetSubroutineUniformLocation;
using gl::glGetSynciv;
using gl::glGetTexBumpParameterfvATI;
using gl::glGetTexBumpParameterivATI;
using gl::glGetTexEnvxvOES;
using gl::glGetTexFilterFuncSGIS;
using gl::glGetTexGenxvOES;
using gl::glGetTexLevelParameterxvOES;
using gl::glGetTexParameterIiv;
using gl::glGetTexParameterIivEXT;
using gl::glGetTexParameterIuiv;
using gl::glGetTexParameterIuivEXT;
using gl::glGetTexParameterPointervAPPLE;
using gl::glGetTexParameterxvOES;
using gl::glGetTextureHandleARB;
using gl::glGetTextureHandleNV;
using gl::glGetTextureImage;
using gl::glGetTextureImageEXT;
using gl::glGetTextureLevelParameterfv;
using gl::glGetTextureLevelParameterfvEXT;
using gl::glGetTextureLevelParameteriv;
using gl::glGetTextureLevelParameterivEXT;
using gl::glGetTextureParameterfv;
using gl::glGetTextureParameterfvEXT;
using gl::glGetTextureParameterIiv;
using gl::glGetTextureParameterIivEXT;
using gl::glGetTextureParameterIuiv;
using gl::glGetTextureParameterIuivEXT;
using gl::glGetTextureParameteriv;
using gl::glGetTextureParameterivEXT;
using gl::glGetTextureSamplerHandleARB;
using gl::glGetTextureSamplerHandleNV;
using gl::glGetTextureSubImage;
using gl::glGetTrackMatrixivNV;
using gl::glGetTransformFeedbacki64_v;
using gl::glGetTransformFeedbacki_v;
using gl::glGetTransformFeedbackiv;
using gl::glGetTransformFeedbackVarying;
using gl::glGetTransformFeedbackVaryingEXT;
using gl::glGetTransformFeedbackVaryingNV;
using gl::glGetUniformBlockIndex;
using gl::glGetUniformBufferSizeEXT;
using gl::glGetUniformdv;
using gl::glGetUniformfv;
using gl::glGetUniformfvARB;
using gl::glGetUniformi64vARB;
using gl::glGetUniformi64vNV;
using gl::glGetUniformIndices;
using gl::glGetUniformiv;
using gl::glGetUniformivARB;
using gl::glGetUniformLocation;
using gl::glGetUniformLocationARB;
using gl::glGetUniformOffsetEXT;
using gl::glGetUniformSubroutineuiv;
using gl::glGetUniformui64vARB;
using gl::glGetUniformui64vNV;
using gl::glGetUniformuiv;
using gl::glGetUniformuivEXT;
using gl::glGetUnsignedBytei_vEXT;
using gl::glGetUnsignedBytevEXT;
using gl::glGetVariantArrayObjectfvATI;
using gl::glGetVariantArrayObjectivATI;
using gl::glGetVariantBooleanvEXT;
using gl::glGetVariantFloatvEXT;
using gl::glGetVariantIntegervEXT;
using gl::glGetVariantPointervEXT;
using gl::glGetVaryingLocationNV;
using gl::glGetVertexArrayIndexed64iv;
using gl::glGetVertexArrayIndexediv;
using gl::glGetVertexArrayIntegeri_vEXT;
using gl::glGetVertexArrayIntegervEXT;
using gl::glGetVertexArrayiv;
using gl::glGetVertexArrayPointeri_vEXT;
using gl::glGetVertexArrayPointervEXT;
using gl::glGetVertexAttribArrayObjectfvATI;
using gl::glGetVertexAttribArrayObjectivATI;
using gl::glGetVertexAttribdv;
using gl::glGetVertexAttribdvARB;
using gl::glGetVertexAttribdvNV;
using gl::glGetVertexAttribfv;
using gl::glGetVertexAttribfvARB;
using gl::glGetVertexAttribfvNV;
using gl::glGetVertexAttribIiv;
using gl::glGetVertexAttribIivEXT;
using gl::glGetVertexAttribIuiv;
using gl::glGetVertexAttribIuivEXT;
using gl::glGetVertexAttribiv;
using gl::glGetVertexAttribivARB;
using gl::glGetVertexAttribivNV;
using gl::glGetVertexAttribLdv;
using gl::glGetVertexAttribLdvEXT;
using gl::glGetVertexAttribLi64vNV;
using gl::glGetVertexAttribLui64vARB;
using gl::glGetVertexAttribLui64vNV;
using gl::glGetVertexAttribPointerv;
using gl::glGetVertexAttribPointervARB;
using gl::glGetVertexAttribPointervNV;
using gl::glGetVideoCaptureivNV;
using gl::glGetVideoCaptureStreamdvNV;
using gl::glGetVideoCaptureStreamfvNV;
using gl::glGetVideoCaptureStreamivNV;
using gl::glGetVideoi64vNV;
using gl::glGetVideoivNV;
using gl::glGetVideoui64vNV;
using gl::glGetVideouivNV;
using gl::glGetVkProcAddrNV;
using gl::glGlobalAlphaFactorbSUN;
using gl::glGlobalAlphaFactordSUN;
using gl::glGlobalAlphaFactorfSUN;
using gl::glGlobalAlphaFactoriSUN;
using gl::glGlobalAlphaFactorsSUN;
using gl::glGlobalAlphaFactorubSUN;
using gl::glGlobalAlphaFactoruiSUN;
using gl::glGlobalAlphaFactorusSUN;
using gl::glHintPGI;
using gl::glHistogram;
using gl::glHistogramEXT;
using gl::glIglooInterfaceSGIX;
using gl::glImageTransformParameterfHP;
using gl::glImageTransformParameterfvHP;
using gl::glImageTransformParameteriHP;
using gl::glImageTransformParameterivHP;
using gl::glImportMemoryFdEXT;
using gl::glImportMemoryWin32HandleEXT;
using gl::glImportMemoryWin32NameEXT;
using gl::glImportSemaphoreFdEXT;
using gl::glImportSemaphoreWin32HandleEXT;
using gl::glImportSemaphoreWin32NameEXT;
using gl::glImportSyncEXT;
using gl::glIndexFormatNV;
using gl::glIndexFuncEXT;
using gl::glIndexMaterialEXT;
using gl::glIndexPointerEXT;
using gl::glIndexPointerListIBM;
using gl::glIndexxOES;
using gl::glIndexxvOES;
using gl::glInsertComponentEXT;
using gl::glInsertEventMarkerEXT;
using gl::glInstrumentsBufferSGIX;
using gl::glInterpolatePathsNV;
using gl::glInvalidateBufferData;
using gl::glInvalidateBufferSubData;
using gl::glInvalidateFramebuffer;
using gl::glInvalidateNamedFramebufferData;
using gl::glInvalidateNamedFramebufferSubData;
using gl::glInvalidateSubFramebuffer;
using gl::glInvalidateTexImage;
using gl::glInvalidateTexSubImage;
using gl::glIsAsyncMarkerSGIX;
using gl::glIsBufferARB;
using gl::glIsBufferResidentNV;
using gl::glIsCommandListNV;
using gl::glIsEnabledi;
using gl::glIsEnabledIndexedEXT;
using gl::glIsFenceAPPLE;
using gl::glIsFenceNV;
using gl::glIsFramebuffer;
using gl::glIsFramebufferEXT;
using gl::glIsImageHandleResidentARB;
using gl::glIsImageHandleResidentNV;
using gl::glIsMemoryObjectEXT;
using gl::glIsNameAMD;
using gl::glIsNamedBufferResidentNV;
using gl::glIsNamedStringARB;
using gl::glIsObjectBufferATI;
using gl::glIsOcclusionQueryNV;
using gl::glIsPathNV;
using gl::glIsPointInFillPathNV;
using gl::glIsPointInStrokePathNV;
using gl::glIsProgram;
using gl::glIsProgramARB;
using gl::glIsProgramNV;
using gl::glIsProgramPipeline;
using gl::glIsProgramPipelineEXT;
using gl::glIsQueryARB;
using gl::glIsRenderbuffer;
using gl::glIsRenderbufferEXT;
using gl::glIsSampler;
using gl::glIsSemaphoreEXT;
using gl::glIsShader;
using gl::glIsStateNV;
using gl::glIsSync;
using gl::glIsTextureEXT;
using gl::glIsTextureHandleResidentARB;
using gl::glIsTextureHandleResidentNV;
using gl::glIsTransformFeedback;
using gl::glIsTransformFeedbackNV;
using gl::glIsVariantEnabledEXT;
using gl::glIsVertexArray;
using gl::glIsVertexArrayAPPLE;
using gl::glIsVertexAttribEnabledAPPLE;
using gl::glLabelObjectEXT;
using gl::glLGPUCopyImageSubDataNVX;
using gl::glLGPUInterlockNVX;
using gl::glLGPUNamedBufferSubDataNVX;
using gl::glLightEnviSGIX;
using gl::glLightModelxOES;
using gl::glLightModelxvOES;
using gl::glLightxOES;
using gl::glLightxvOES;
using gl::glLineWidthxOES;
using gl::glLinkProgram;
using gl::glLinkProgramARB;
using gl::glListDrawCommandsStatesClientNV;
using gl::glListParameterfSGIX;
using gl::glListParameterfvSGIX;
using gl::glListParameteriSGIX;
using gl::glListParameterivSGIX;
using gl::glLoadIdentityDeformationMapSGIX;
using gl::glLoadMatrixxOES;
using gl::glLoadProgramNV;
using gl::glLoadTransposeMatrixdARB;
using gl::glLoadTransposeMatrixfARB;
using gl::glLoadTransposeMatrixxOES;
using gl::glLockArraysEXT;
using gl::glMakeBufferNonResidentNV;
using gl::glMakeBufferResidentNV;
using gl::glMakeImageHandleNonResidentARB;
using gl::glMakeImageHandleNonResidentNV;
using gl::glMakeImageHandleResidentARB;
using gl::glMakeImageHandleResidentNV;
using gl::glMakeNamedBufferNonResidentNV;
using gl::glMakeNamedBufferResidentNV;
using gl::glMakeTextureHandleNonResidentARB;
using gl::glMakeTextureHandleNonResidentNV;
using gl::glMakeTextureHandleResidentARB;
using gl::glMakeTextureHandleResidentNV;
using gl::glMap1xOES;
using gl::glMap2xOES;
using gl::glMapBufferARB;
using gl::glMapBufferRange;
using gl::glMapControlPointsNV;
using gl::glMapGrid1xOES;
using gl::glMapGrid2xOES;
using gl::glMapNamedBuffer;
using gl::glMapNamedBufferEXT;
using gl::glMapNamedBufferRange;
using gl::glMapNamedBufferRangeEXT;
using gl::glMapObjectBufferATI;
using gl::glMapParameterfvNV;
using gl::glMapParameterivNV;
using gl::glMapTexture2DINTEL;
using gl::glMapVertexAttrib1dAPPLE;
using gl::glMapVertexAttrib1fAPPLE;
using gl::glMapVertexAttrib2dAPPLE;
using gl::glMapVertexAttrib2fAPPLE;
using gl::glMaterialxOES;
using gl::glMaterialxvOES;
using gl::glMatrixFrustumEXT;
using gl::glMatrixIndexPointerARB;
using gl::glMatrixIndexubvARB;
using gl::glMatrixIndexuivARB;
using gl::glMatrixIndexusvARB;
using gl::glMatrixLoad3x2fNV;
using gl::glMatrixLoad3x3fNV;
using gl::glMatrixLoaddEXT;
using gl::glMatrixLoadfEXT;
using gl::glMatrixLoadIdentityEXT;
using gl::glMatrixLoadTranspose3x3fNV;
using gl::glMatrixLoadTransposedEXT;
using gl::glMatrixLoadTransposefEXT;
using gl::glMatrixMult3x2fNV;
using gl::glMatrixMult3x3fNV;
using gl::glMatrixMultdEXT;
using gl::glMatrixMultfEXT;
using gl::glMatrixMultTranspose3x3fNV;
using gl::glMatrixMultTransposedEXT;
using gl::glMatrixMultTransposefEXT;
using gl::glMatrixOrthoEXT;
using gl::glMatrixPopEXT;
using gl::glMatrixPushEXT;
using gl::glMatrixRotatedEXT;
using gl::glMatrixRotatefEXT;
using gl::glMatrixScaledEXT;
using gl::glMatrixScalefEXT;
using gl::glMatrixTranslatedEXT;
using gl::glMatrixTranslatefEXT;
using gl::glMaxShaderCompilerThreadsARB;
using gl::glMaxShaderCompilerThreadsKHR;
using gl::glMemoryBarrier;
using gl::glMemoryBarrierByRegion;
using gl::glMemoryBarrierEXT;
using gl::glMemoryObjectParameterivEXT;
using gl::glMinmax;
using gl::glMinmaxEXT;
using gl::glMinSampleShading;
using gl::glMinSampleShadingARB;
using gl::glMulticastBarrierNV;
using gl::glMulticastBlitFramebufferNV;
using gl::glMulticastBufferSubDataNV;
using gl::glMulticastCopyBufferSubDataNV;
using gl::glMulticastCopyImageSubDataNV;
using gl::glMulticastFramebufferSampleLocationsfvNV;
using gl::glMulticastGetQueryObjecti64vNV;
using gl::glMulticastGetQueryObjectivNV;
using gl::glMulticastGetQueryObjectui64vNV;
using gl::glMulticastGetQueryObjectuivNV;
using gl::glMulticastScissorArrayvNVX;
using gl::glMulticastViewportArrayvNVX;
using gl::glMulticastViewportPositionWScaleNVX;
using gl::glMulticastWaitSyncNV;
using gl::glMultiDrawArraysEXT;
using gl::glMultiDrawArraysIndirect;
using gl::glMultiDrawArraysIndirectAMD;
using gl::glMultiDrawArraysIndirectBindlessCountNV;
using gl::glMultiDrawArraysIndirectBindlessNV;
using gl::glMultiDrawArraysIndirectCount;
using gl::glMultiDrawArraysIndirectCountARB;
using gl::glMultiDrawElementArrayAPPLE;
using gl::glMultiDrawElementsBaseVertex;
using gl::glMultiDrawElementsEXT;
using gl::glMultiDrawElementsIndirect;
using gl::glMultiDrawElementsIndirectAMD;
using gl::glMultiDrawElementsIndirectBindlessCountNV;
using gl::glMultiDrawElementsIndirectBindlessNV;
using gl::glMultiDrawElementsIndirectCount;
using gl::glMultiDrawElementsIndirectCountARB;
using gl::glMultiDrawMeshTasksIndirectCountNV;
using gl::glMultiDrawMeshTasksIndirectNV;
using gl::glMultiDrawRangeElementArrayAPPLE;
using gl::glMultiModeDrawArraysIBM;
using gl::glMultiModeDrawElementsIBM;
using gl::glMultiTexBufferEXT;
using gl::glMultiTexCoord1bOES;
using gl::glMultiTexCoord1bvOES;
using gl::glMultiTexCoord1dARB;
using gl::glMultiTexCoord1dvARB;
using gl::glMultiTexCoord1fARB;
using gl::glMultiTexCoord1fvARB;
using gl::glMultiTexCoord1hNV;
using gl::glMultiTexCoord1hvNV;
using gl::glMultiTexCoord1iARB;
using gl::glMultiTexCoord1ivARB;
using gl::glMultiTexCoord1sARB;
using gl::glMultiTexCoord1svARB;
using gl::glMultiTexCoord1xOES;
using gl::glMultiTexCoord1xvOES;
using gl::glMultiTexCoord2bOES;
using gl::glMultiTexCoord2bvOES;
using gl::glMultiTexCoord2dARB;
using gl::glMultiTexCoord2dvARB;
using gl::glMultiTexCoord2fARB;
using gl::glMultiTexCoord2fvARB;
using gl::glMultiTexCoord2hNV;
using gl::glMultiTexCoord2hvNV;
using gl::glMultiTexCoord2iARB;
using gl::glMultiTexCoord2ivARB;
using gl::glMultiTexCoord2sARB;
using gl::glMultiTexCoord2svARB;
using gl::glMultiTexCoord2xOES;
using gl::glMultiTexCoord2xvOES;
using gl::glMultiTexCoord3bOES;
using gl::glMultiTexCoord3bvOES;
using gl::glMultiTexCoord3dARB;
using gl::glMultiTexCoord3dvARB;
using gl::glMultiTexCoord3fARB;
using gl::glMultiTexCoord3fvARB;
using gl::glMultiTexCoord3hNV;
using gl::glMultiTexCoord3hvNV;
using gl::glMultiTexCoord3iARB;
using gl::glMultiTexCoord3ivARB;
using gl::glMultiTexCoord3sARB;
using gl::glMultiTexCoord3svARB;
using gl::glMultiTexCoord3xOES;
using gl::glMultiTexCoord3xvOES;
using gl::glMultiTexCoord4bOES;
using gl::glMultiTexCoord4bvOES;
using gl::glMultiTexCoord4dARB;
using gl::glMultiTexCoord4dvARB;
using gl::glMultiTexCoord4fARB;
using gl::glMultiTexCoord4fvARB;
using gl::glMultiTexCoord4hNV;
using gl::glMultiTexCoord4hvNV;
using gl::glMultiTexCoord4iARB;
using gl::glMultiTexCoord4ivARB;
using gl::glMultiTexCoord4sARB;
using gl::glMultiTexCoord4svARB;
using gl::glMultiTexCoord4xOES;
using gl::glMultiTexCoord4xvOES;
using gl::glMultiTexCoordP1ui;
using gl::glMultiTexCoordP1uiv;
using gl::glMultiTexCoordP2ui;
using gl::glMultiTexCoordP2uiv;
using gl::glMultiTexCoordP3ui;
using gl::glMultiTexCoordP3uiv;
using gl::glMultiTexCoordP4ui;
using gl::glMultiTexCoordP4uiv;
using gl::glMultiTexCoordPointerEXT;
using gl::glMultiTexEnvfEXT;
using gl::glMultiTexEnvfvEXT;
using gl::glMultiTexEnviEXT;
using gl::glMultiTexEnvivEXT;
using gl::glMultiTexGendEXT;
using gl::glMultiTexGendvEXT;
using gl::glMultiTexGenfEXT;
using gl::glMultiTexGenfvEXT;
using gl::glMultiTexGeniEXT;
using gl::glMultiTexGenivEXT;
using gl::glMultiTexImage1DEXT;
using gl::glMultiTexImage2DEXT;
using gl::glMultiTexImage3DEXT;
using gl::glMultiTexParameterfEXT;
using gl::glMultiTexParameterfvEXT;
using gl::glMultiTexParameteriEXT;
using gl::glMultiTexParameterIivEXT;
using gl::glMultiTexParameterIuivEXT;
using gl::glMultiTexParameterivEXT;
using gl::glMultiTexRenderbufferEXT;
using gl::glMultiTexSubImage1DEXT;
using gl::glMultiTexSubImage2DEXT;
using gl::glMultiTexSubImage3DEXT;
using gl::glMultMatrixxOES;
using gl::glMultTransposeMatrixdARB;
using gl::glMultTransposeMatrixfARB;
using gl::glMultTransposeMatrixxOES;
using gl::glNamedBufferAttachMemoryNV;
using gl::glNamedBufferData;
using gl::glNamedBufferDataEXT;
using gl::glNamedBufferPageCommitmentARB;
using gl::glNamedBufferPageCommitmentEXT;
using gl::glNamedBufferPageCommitmentMemNV;
using gl::glNamedBufferStorage;
using gl::glNamedBufferStorageEXT;
using gl::glNamedBufferStorageExternalEXT;
using gl::glNamedBufferStorageMemEXT;
using gl::glNamedBufferSubData;
using gl::glNamedBufferSubDataEXT;
using gl::glNamedCopyBufferSubDataEXT;
using gl::glNamedFramebufferDrawBuffer;
using gl::glNamedFramebufferDrawBuffers;
using gl::glNamedFramebufferParameteri;
using gl::glNamedFramebufferParameteriEXT;
using gl::glNamedFramebufferReadBuffer;
using gl::glNamedFramebufferRenderbuffer;
using gl::glNamedFramebufferRenderbufferEXT;
using gl::glNamedFramebufferSampleLocationsfvARB;
using gl::glNamedFramebufferSampleLocationsfvNV;
using gl::glNamedFramebufferSamplePositionsfvAMD;
using gl::glNamedFramebufferTexture;
using gl::glNamedFramebufferTexture1DEXT;
using gl::glNamedFramebufferTexture2DEXT;
using gl::glNamedFramebufferTexture3DEXT;
using gl::glNamedFramebufferTextureEXT;
using gl::glNamedFramebufferTextureFaceEXT;
using gl::glNamedFramebufferTextureLayer;
using gl::glNamedFramebufferTextureLayerEXT;
using gl::glNamedFramebufferTextureMultiviewOVR;
using gl::glNamedProgramLocalParameter4dEXT;
using gl::glNamedProgramLocalParameter4dvEXT;
using gl::glNamedProgramLocalParameter4fEXT;
using gl::glNamedProgramLocalParameter4fvEXT;
using gl::glNamedProgramLocalParameterI4iEXT;
using gl::glNamedProgramLocalParameterI4ivEXT;
using gl::glNamedProgramLocalParameterI4uiEXT;
using gl::glNamedProgramLocalParameterI4uivEXT;
using gl::glNamedProgramLocalParameters4fvEXT;
using gl::glNamedProgramLocalParametersI4ivEXT;
using gl::glNamedProgramLocalParametersI4uivEXT;
using gl::glNamedProgramStringEXT;
using gl::glNamedRenderbufferStorage;
using gl::glNamedRenderbufferStorageEXT;
using gl::glNamedRenderbufferStorageMultisample;
using gl::glNamedRenderbufferStorageMultisampleAdvancedAMD;
using gl::glNamedRenderbufferStorageMultisampleCoverageEXT;
using gl::glNamedRenderbufferStorageMultisampleEXT;
using gl::glNamedStringARB;
using gl::glNewObjectBufferATI;
using gl::glNormal3fVertex3fSUN;
using gl::glNormal3fVertex3fvSUN;
using gl::glNormal3hNV;
using gl::glNormal3hvNV;
using gl::glNormal3xOES;
using gl::glNormal3xvOES;
using gl::glNormalFormatNV;
using gl::glNormalP3ui;
using gl::glNormalP3uiv;
using gl::glNormalPointerEXT;
using gl::glNormalPointerListIBM;
using gl::glNormalPointervINTEL;
using gl::glNormalStream3bATI;
using gl::glNormalStream3bvATI;
using gl::glNormalStream3dATI;
using gl::glNormalStream3dvATI;
using gl::glNormalStream3fATI;
using gl::glNormalStream3fvATI;
using gl::glNormalStream3iATI;
using gl::glNormalStream3ivATI;
using gl::glNormalStream3sATI;
using gl::glNormalStream3svATI;
using gl::glObjectLabel;
using gl::glObjectLabelKHR;
using gl::glObjectPtrLabel;
using gl::glObjectPtrLabelKHR;
using gl::glObjectPurgeableAPPLE;
using gl::glObjectUnpurgeableAPPLE;
using gl::glOrthofOES;
using gl::glOrthoxOES;
using gl::glPassTexCoordATI;
using gl::glPassThroughxOES;
using gl::glPatchParameterfv;
using gl::glPatchParameteri;
using gl::glPathColorGenNV;
using gl::glPathCommandsNV;
using gl::glPathCoordsNV;
using gl::glPathCoverDepthFuncNV;
using gl::glPathDashArrayNV;
using gl::glPathFogGenNV;
using gl::glPathGlyphIndexArrayNV;
using gl::glPathGlyphIndexRangeNV;
using gl::glPathGlyphRangeNV;
using gl::glPathGlyphsNV;
using gl::glPathMemoryGlyphIndexArrayNV;
using gl::glPathParameterfNV;
using gl::glPathParameterfvNV;
using gl::glPathParameteriNV;
using gl::glPathParameterivNV;
using gl::glPathStencilDepthOffsetNV;
using gl::glPathStencilFuncNV;
using gl::glPathStringNV;
using gl::glPathSubCommandsNV;
using gl::glPathSubCoordsNV;
using gl::glPathTexGenNV;
using gl::glPauseTransformFeedback;
using gl::glPauseTransformFeedbackNV;
using gl::glPixelDataRangeNV;
using gl::glPixelMapx;
using gl::glPixelStorex;
using gl::glPixelTexGenParameterfSGIS;
using gl::glPixelTexGenParameterfvSGIS;
using gl::glPixelTexGenParameteriSGIS;
using gl::glPixelTexGenParameterivSGIS;
using gl::glPixelTexGenSGIX;
using gl::glPixelTransferxOES;
using gl::glPixelTransformParameterfEXT;
using gl::glPixelTransformParameterfvEXT;
using gl::glPixelTransformParameteriEXT;
using gl::glPixelTransformParameterivEXT;
using gl::glPixelZoomxOES;
using gl::glPNTrianglesfATI;
using gl::glPNTrianglesiATI;
using gl::glPointAlongPathNV;
using gl::glPointParameterfARB;
using gl::glPointParameterfEXT;
using gl::glPointParameterfSGIS;
using gl::glPointParameterfvARB;
using gl::glPointParameterfvEXT;
using gl::glPointParameterfvSGIS;
using gl::glPointParameteriNV;
using gl::glPointParameterivNV;
using gl::glPointParameterxOES;
using gl::glPointParameterxvOES;
using gl::glPointSizexOES;
using gl::glPollAsyncSGIX;
using gl::glPollInstrumentsSGIX;
using gl::glPolygonOffsetClamp;
using gl::glPolygonOffsetClampEXT;
using gl::glPolygonOffsetEXT;
using gl::glPolygonOffsetxOES;
using gl::glPopDebugGroup;
using gl::glPopDebugGroupKHR;
using gl::glPopGroupMarkerEXT;
using gl::glPresentFrameDualFillNV;
using gl::glPresentFrameKeyedNV;
using gl::glPrimitiveBoundingBoxARB;
using gl::glPrimitiveRestartIndex;
using gl::glPrimitiveRestartIndexNV;
using gl::glPrimitiveRestartNV;
using gl::glPrioritizeTexturesEXT;
using gl::glPrioritizeTexturesxOES;
using gl::glProgramBinary;
using gl::glProgramBufferParametersfvNV;
using gl::glProgramBufferParametersIivNV;
using gl::glProgramBufferParametersIuivNV;
using gl::glProgramEnvParameter4dARB;
using gl::glProgramEnvParameter4dvARB;
using gl::glProgramEnvParameter4fARB;
using gl::glProgramEnvParameter4fvARB;
using gl::glProgramEnvParameterI4iNV;
using gl::glProgramEnvParameterI4ivNV;
using gl::glProgramEnvParameterI4uiNV;
using gl::glProgramEnvParameterI4uivNV;
using gl::glProgramEnvParameters4fvEXT;
using gl::glProgramEnvParametersI4ivNV;
using gl::glProgramEnvParametersI4uivNV;
using gl::glProgramLocalParameter4dARB;
using gl::glProgramLocalParameter4dvARB;
using gl::glProgramLocalParameter4fARB;
using gl::glProgramLocalParameter4fvARB;
using gl::glProgramLocalParameterI4iNV;
using gl::glProgramLocalParameterI4ivNV;
using gl::glProgramLocalParameterI4uiNV;
using gl::glProgramLocalParameterI4uivNV;
using gl::glProgramLocalParameters4fvEXT;
using gl::glProgramLocalParametersI4ivNV;
using gl::glProgramLocalParametersI4uivNV;
using gl::glProgramNamedParameter4dNV;
using gl::glProgramNamedParameter4dvNV;
using gl::glProgramNamedParameter4fNV;
using gl::glProgramNamedParameter4fvNV;
using gl::glProgramParameter4dNV;
using gl::glProgramParameter4dvNV;
using gl::glProgramParameter4fNV;
using gl::glProgramParameter4fvNV;
using gl::glProgramParameteri;
using gl::glProgramParameteriARB;
using gl::glProgramParameteriEXT;
using gl::glProgramParameters4dvNV;
using gl::glProgramParameters4fvNV;
using gl::glProgramPathFragmentInputGenNV;
using gl::glProgramStringARB;
using gl::glProgramSubroutineParametersuivNV;
using gl::glProgramUniform1d;
using gl::glProgramUniform1dEXT;
using gl::glProgramUniform1dv;
using gl::glProgramUniform1dvEXT;
using gl::glProgramUniform1f;
using gl::glProgramUniform1fEXT;
using gl::glProgramUniform1fv;
using gl::glProgramUniform1fvEXT;
using gl::glProgramUniform1i;
using gl::glProgramUniform1i64ARB;
using gl::glProgramUniform1i64NV;
using gl::glProgramUniform1i64vARB;
using gl::glProgramUniform1i64vNV;
using gl::glProgramUniform1iEXT;
using gl::glProgramUniform1iv;
using gl::glProgramUniform1ivEXT;
using gl::glProgramUniform1ui;
using gl::glProgramUniform1ui64ARB;
using gl::glProgramUniform1ui64NV;
using gl::glProgramUniform1ui64vARB;
using gl::glProgramUniform1ui64vNV;
using gl::glProgramUniform1uiEXT;
using gl::glProgramUniform1uiv;
using gl::glProgramUniform1uivEXT;
using gl::glProgramUniform2d;
using gl::glProgramUniform2dEXT;
using gl::glProgramUniform2dv;
using gl::glProgramUniform2dvEXT;
using gl::glProgramUniform2f;
using gl::glProgramUniform2fEXT;
using gl::glProgramUniform2fv;
using gl::glProgramUniform2fvEXT;
using gl::glProgramUniform2i;
using gl::glProgramUniform2i64ARB;
using gl::glProgramUniform2i64NV;
using gl::glProgramUniform2i64vARB;
using gl::glProgramUniform2i64vNV;
using gl::glProgramUniform2iEXT;
using gl::glProgramUniform2iv;
using gl::glProgramUniform2ivEXT;
using gl::glProgramUniform2ui;
using gl::glProgramUniform2ui64ARB;
using gl::glProgramUniform2ui64NV;
using gl::glProgramUniform2ui64vARB;
using gl::glProgramUniform2ui64vNV;
using gl::glProgramUniform2uiEXT;
using gl::glProgramUniform2uiv;
using gl::glProgramUniform2uivEXT;
using gl::glProgramUniform3d;
using gl::glProgramUniform3dEXT;
using gl::glProgramUniform3dv;
using gl::glProgramUniform3dvEXT;
using gl::glProgramUniform3f;
using gl::glProgramUniform3fEXT;
using gl::glProgramUniform3fv;
using gl::glProgramUniform3fvEXT;
using gl::glProgramUniform3i;
using gl::glProgramUniform3i64ARB;
using gl::glProgramUniform3i64NV;
using gl::glProgramUniform3i64vARB;
using gl::glProgramUniform3i64vNV;
using gl::glProgramUniform3iEXT;
using gl::glProgramUniform3iv;
using gl::glProgramUniform3ivEXT;
using gl::glProgramUniform3ui;
using gl::glProgramUniform3ui64ARB;
using gl::glProgramUniform3ui64NV;
using gl::glProgramUniform3ui64vARB;
using gl::glProgramUniform3ui64vNV;
using gl::glProgramUniform3uiEXT;
using gl::glProgramUniform3uiv;
using gl::glProgramUniform3uivEXT;
using gl::glProgramUniform4d;
using gl::glProgramUniform4dEXT;
using gl::glProgramUniform4dv;
using gl::glProgramUniform4dvEXT;
using gl::glProgramUniform4f;
using gl::glProgramUniform4fEXT;
using gl::glProgramUniform4fv;
using gl::glProgramUniform4fvEXT;
using gl::glProgramUniform4i;
using gl::glProgramUniform4i64ARB;
using gl::glProgramUniform4i64NV;
using gl::glProgramUniform4i64vARB;
using gl::glProgramUniform4i64vNV;
using gl::glProgramUniform4iEXT;
using gl::glProgramUniform4iv;
using gl::glProgramUniform4ivEXT;
using gl::glProgramUniform4ui;
using gl::glProgramUniform4ui64ARB;
using gl::glProgramUniform4ui64NV;
using gl::glProgramUniform4ui64vARB;
using gl::glProgramUniform4ui64vNV;
using gl::glProgramUniform4uiEXT;
using gl::glProgramUniform4uiv;
using gl::glProgramUniform4uivEXT;
using gl::glProgramUniformHandleui64ARB;
using gl::glProgramUniformHandleui64NV;
using gl::glProgramUniformHandleui64vARB;
using gl::glProgramUniformHandleui64vNV;
using gl::glProgramUniformMatrix2dv;
using gl::glProgramUniformMatrix2dvEXT;
using gl::glProgramUniformMatrix2fv;
using gl::glProgramUniformMatrix2fvEXT;
using gl::glProgramUniformMatrix2x3dv;
using gl::glProgramUniformMatrix2x3dvEXT;
using gl::glProgramUniformMatrix2x3fv;
using gl::glProgramUniformMatrix2x3fvEXT;
using gl::glProgramUniformMatrix2x4dv;
using gl::glProgramUniformMatrix2x4dvEXT;
using gl::glProgramUniformMatrix2x4fv;
using gl::glProgramUniformMatrix2x4fvEXT;
using gl::glProgramUniformMatrix3dv;
using gl::glProgramUniformMatrix3dvEXT;
using gl::glProgramUniformMatrix3fv;
using gl::glProgramUniformMatrix3fvEXT;
using gl::glProgramUniformMatrix3x2dv;
using gl::glProgramUniformMatrix3x2dvEXT;
using gl::glProgramUniformMatrix3x2fv;
using gl::glProgramUniformMatrix3x2fvEXT;
using gl::glProgramUniformMatrix3x4dv;
using gl::glProgramUniformMatrix3x4dvEXT;
using gl::glProgramUniformMatrix3x4fv;
using gl::glProgramUniformMatrix3x4fvEXT;
using gl::glProgramUniformMatrix4dv;
using gl::glProgramUniformMatrix4dvEXT;
using gl::glProgramUniformMatrix4fv;
using gl::glProgramUniformMatrix4fvEXT;
using gl::glProgramUniformMatrix4x2dv;
using gl::glProgramUniformMatrix4x2dvEXT;
using gl::glProgramUniformMatrix4x2fv;
using gl::glProgramUniformMatrix4x2fvEXT;
using gl::glProgramUniformMatrix4x3dv;
using gl::glProgramUniformMatrix4x3dvEXT;
using gl::glProgramUniformMatrix4x3fv;
using gl::glProgramUniformMatrix4x3fvEXT;
using gl::glProgramUniformui64NV;
using gl::glProgramUniformui64vNV;
using gl::glProgramVertexLimitNV;
using gl::glProvokingVertex;
using gl::glProvokingVertexEXT;
using gl::glPushClientAttribDefaultEXT;
using gl::glPushDebugGroup;
using gl::glPushDebugGroupKHR;
using gl::glPushGroupMarkerEXT;
using gl::glQueryCounter;
using gl::glQueryMatrixxOES;
using gl::glQueryObjectParameteruiAMD;
using gl::glQueryResourceNV;
using gl::glQueryResourceTagNV;
using gl::glRasterPos2xOES;
using gl::glRasterPos2xvOES;
using gl::glRasterPos3xOES;
using gl::glRasterPos3xvOES;
using gl::glRasterPos4xOES;
using gl::glRasterPos4xvOES;
using gl::glRasterSamplesEXT;
using gl::glReadInstrumentsSGIX;
using gl::glReadnPixels;
using gl::glReadnPixelsARB;
using gl::glReadnPixelsKHR;
using gl::glRectxOES;
using gl::glRectxvOES;
using gl::glReferencePlaneSGIX;
using gl::glReleaseKeyedMutexWin32EXT;
using gl::glReleaseShaderCompiler;
using gl::glRenderbufferStorage;
using gl::glRenderbufferStorageEXT;
using gl::glRenderbufferStorageMultisample;
using gl::glRenderbufferStorageMultisampleAdvancedAMD;
using gl::glRenderbufferStorageMultisampleCoverageNV;
using gl::glRenderbufferStorageMultisampleEXT;
using gl::glRenderGpuMaskNV;
using gl::glReplacementCodePointerSUN;
using gl::glReplacementCodeubSUN;
using gl::glReplacementCodeubvSUN;
using gl::glReplacementCodeuiColor3fVertex3fSUN;
using gl::glReplacementCodeuiColor3fVertex3fvSUN;
using gl::glReplacementCodeuiColor4fNormal3fVertex3fSUN;
using gl::glReplacementCodeuiColor4fNormal3fVertex3fvSUN;
using gl::glReplacementCodeuiColor4ubVertex3fSUN;
using gl::glReplacementCodeuiColor4ubVertex3fvSUN;
using gl::glReplacementCodeuiNormal3fVertex3fSUN;
using gl::glReplacementCodeuiNormal3fVertex3fvSUN;
using gl::glReplacementCodeuiSUN;
using gl::glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN;
using gl::glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN;
using gl::glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN;
using gl::glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN;
using gl::glReplacementCodeuiTexCoord2fVertex3fSUN;
using gl::glReplacementCodeuiTexCoord2fVertex3fvSUN;
using gl::glReplacementCodeuiVertex3fSUN;
using gl::glReplacementCodeuiVertex3fvSUN;
using gl::glReplacementCodeuivSUN;
using gl::glReplacementCodeusSUN;
using gl::glReplacementCodeusvSUN;
using gl::glRequestResidentProgramsNV;
using gl::glResetHistogram;
using gl::glResetHistogramEXT;
using gl::glResetMemoryObjectParameterNV;
using gl::glResetMinmax;
using gl::glResetMinmaxEXT;
using gl::glResizeBuffersMESA;
using gl::glResolveDepthValuesNV;
using gl::glResumeTransformFeedback;
using gl::glResumeTransformFeedbackNV;
using gl::glRotatexOES;
using gl::glSampleCoverageARB;
using gl::glSampleCoveragexOES;
using gl::glSampleMapATI;
using gl::glSampleMaskEXT;
using gl::glSampleMaski;
using gl::glSampleMaskIndexedNV;
using gl::glSampleMaskSGIS;
using gl::glSamplePatternEXT;
using gl::glSamplePatternSGIS;
using gl::glSamplerParameterf;
using gl::glSamplerParameterfv;
using gl::glSamplerParameteri;
using gl::glSamplerParameterIiv;
using gl::glSamplerParameterIuiv;
using gl::glSamplerParameteriv;
using gl::glScalexOES;
using gl::glScissorArrayv;
using gl::glScissorExclusiveArrayvNV;
using gl::glScissorExclusiveNV;
using gl::glScissorIndexed;
using gl::glScissorIndexedv;
using gl::glSecondaryColor3bEXT;
using gl::glSecondaryColor3bvEXT;
using gl::glSecondaryColor3dEXT;
using gl::glSecondaryColor3dvEXT;
using gl::glSecondaryColor3fEXT;
using gl::glSecondaryColor3fvEXT;
using gl::glSecondaryColor3hNV;
using gl::glSecondaryColor3hvNV;
using gl::glSecondaryColor3iEXT;
using gl::glSecondaryColor3ivEXT;
using gl::glSecondaryColor3sEXT;
using gl::glSecondaryColor3svEXT;
using gl::glSecondaryColor3ubEXT;
using gl::glSecondaryColor3ubvEXT;
using gl::glSecondaryColor3uiEXT;
using gl::glSecondaryColor3uivEXT;
using gl::glSecondaryColor3usEXT;
using gl::glSecondaryColor3usvEXT;
using gl::glSecondaryColorFormatNV;
using gl::glSecondaryColorP3ui;
using gl::glSecondaryColorP3uiv;
using gl::glSecondaryColorPointerEXT;
using gl::glSecondaryColorPointerListIBM;
using gl::glSelectPerfMonitorCountersAMD;
using gl::glSemaphoreParameterivNV;
using gl::glSemaphoreParameterui64vEXT;
using gl::glSeparableFilter2D;
using gl::glSeparableFilter2DEXT;
using gl::glSetFenceAPPLE;
using gl::glSetFenceNV;
using gl::glSetFragmentShaderConstantATI;
using gl::glSetInvariantEXT;
using gl::glSetLocalConstantEXT;
using gl::glSetMultisamplefvAMD;
using gl::glShaderBinary;
using gl::glShaderOp1EXT;
using gl::glShaderOp2EXT;
using gl::glShaderOp3EXT;
using gl::glShaderSource;
using gl::glShaderSourceARB;
using gl::glShaderStorageBlockBinding;
using gl::glShadingRateImageBarrierNV;
using gl::glShadingRateImagePaletteNV;
using gl::glShadingRateSampleOrderCustomNV;
using gl::glShadingRateSampleOrderNV;
using gl::glSharpenTexFuncSGIS;
using gl::glSignalSemaphoreEXT;
using gl::glSignalSemaphoreui64NVX;
using gl::glSignalVkFenceNV;
using gl::glSignalVkSemaphoreNV;
using gl::glSpecializeShader;
using gl::glSpecializeShaderARB;
using gl::glSpriteParameterfSGIX;
using gl::glSpriteParameterfvSGIX;
using gl::glSpriteParameteriSGIX;
using gl::glSpriteParameterivSGIX;
using gl::glStartInstrumentsSGIX;
using gl::glStateCaptureNV;
using gl::glStencilClearTagEXT;
using gl::glStencilFillPathInstancedNV;
using gl::glStencilFillPathNV;
using gl::glStencilFuncSeparate;
using gl::glStencilFuncSeparateATI;
using gl::glStencilMaskSeparate;
using gl::glStencilOpSeparate;
using gl::glStencilOpSeparateATI;
using gl::glStencilOpValueAMD;
using gl::glStencilStrokePathInstancedNV;
using gl::glStencilStrokePathNV;
using gl::glStencilThenCoverFillPathInstancedNV;
using gl::glStencilThenCoverFillPathNV;
using gl::glStencilThenCoverStrokePathInstancedNV;
using gl::glStencilThenCoverStrokePathNV;
using gl::glStopInstrumentsSGIX;
using gl::glStringMarkerGREMEDY;
using gl::glSubpixelPrecisionBiasNV;
using gl::glSwizzleEXT;
using gl::glSyncTextureINTEL;
using gl::glTagSampleBufferSGIX;
using gl::glTangent3bEXT;
using gl::glTangent3bvEXT;
using gl::glTangent3dEXT;
using gl::glTangent3dvEXT;
using gl::glTangent3fEXT;
using gl::glTangent3fvEXT;
using gl::glTangent3iEXT;
using gl::glTangent3ivEXT;
using gl::glTangent3sEXT;
using gl::glTangent3svEXT;
using gl::glTangentPointerEXT;
using gl::glTbufferMask3DFX;
using gl::glTessellationFactorAMD;
using gl::glTessellationModeAMD;
using gl::glTestFenceAPPLE;
using gl::glTestFenceNV;
using gl::glTestObjectAPPLE;
using gl::glTexAttachMemoryNV;
using gl::glTexBuffer;
using gl::glTexBufferARB;
using gl::glTexBufferEXT;
using gl::glTexBufferRange;
using gl::glTexBumpParameterfvATI;
using gl::glTexBumpParameterivATI;
using gl::glTexCoord1bOES;
using gl::glTexCoord1bvOES;
using gl::glTexCoord1hNV;
using gl::glTexCoord1hvNV;
using gl::glTexCoord1xOES;
using gl::glTexCoord1xvOES;
using gl::glTexCoord2bOES;
using gl::glTexCoord2bvOES;
using gl::glTexCoord2fColor3fVertex3fSUN;
using gl::glTexCoord2fColor3fVertex3fvSUN;
using gl::glTexCoord2fColor4fNormal3fVertex3fSUN;
using gl::glTexCoord2fColor4fNormal3fVertex3fvSUN;
using gl::glTexCoord2fColor4ubVertex3fSUN;
using gl::glTexCoord2fColor4ubVertex3fvSUN;
using gl::glTexCoord2fNormal3fVertex3fSUN;
using gl::glTexCoord2fNormal3fVertex3fvSUN;
using gl::glTexCoord2fVertex3fSUN;
using gl::glTexCoord2fVertex3fvSUN;
using gl::glTexCoord2hNV;
using gl::glTexCoord2hvNV;
using gl::glTexCoord2xOES;
using gl::glTexCoord2xvOES;
using gl::glTexCoord3bOES;
using gl::glTexCoord3bvOES;
using gl::glTexCoord3hNV;
using gl::glTexCoord3hvNV;
using gl::glTexCoord3xOES;
using gl::glTexCoord3xvOES;
using gl::glTexCoord4bOES;
using gl::glTexCoord4bvOES;
using gl::glTexCoord4fColor4fNormal3fVertex4fSUN;
using gl::glTexCoord4fColor4fNormal3fVertex4fvSUN;
using gl::glTexCoord4fVertex4fSUN;
using gl::glTexCoord4fVertex4fvSUN;
using gl::glTexCoord4hNV;
using gl::glTexCoord4hvNV;
using gl::glTexCoord4xOES;
using gl::glTexCoord4xvOES;
using gl::glTexCoordFormatNV;
using gl::glTexCoordP1ui;
using gl::glTexCoordP1uiv;
using gl::glTexCoordP2ui;
using gl::glTexCoordP2uiv;
using gl::glTexCoordP3ui;
using gl::glTexCoordP3uiv;
using gl::glTexCoordP4ui;
using gl::glTexCoordP4uiv;
using gl::glTexCoordPointerEXT;
using gl::glTexCoordPointerListIBM;
using gl::glTexCoordPointervINTEL;
using gl::glTexEnvxOES;
using gl::glTexEnvxvOES;
using gl::glTexFilterFuncSGIS;
using gl::glTexGenxOES;
using gl::glTexGenxvOES;
using gl::glTexImage2DMultisample;
using gl::glTexImage2DMultisampleCoverageNV;
using gl::glTexImage3DEXT;
using gl::glTexImage3DMultisample;
using gl::glTexImage3DMultisampleCoverageNV;
using gl::glTexImage4DSGIS;
using gl::glTexPageCommitmentARB;
using gl::glTexPageCommitmentMemNV;
using gl::glTexParameterIiv;
using gl::glTexParameterIivEXT;
using gl::glTexParameterIuiv;
using gl::glTexParameterIuivEXT;
using gl::glTexParameterxOES;
using gl::glTexParameterxvOES;
using gl::glTexRenderbufferNV;
using gl::glTexStorage1D;
using gl::glTexStorage1DEXT;
using gl::glTexStorage2D;
using gl::glTexStorage2DEXT;
using gl::glTexStorage2DMultisample;
using gl::glTexStorage3D;
using gl::glTexStorage3DEXT;
using gl::glTexStorage3DMultisample;
using gl::glTexStorageMem1DEXT;
using gl::glTexStorageMem2DEXT;
using gl::glTexStorageMem2DMultisampleEXT;
using gl::glTexStorageMem3DEXT;
using gl::glTexStorageMem3DMultisampleEXT;
using gl::glTexStorageSparseAMD;
using gl::glTexSubImage1DEXT;
using gl::glTexSubImage2DEXT;
using gl::glTexSubImage3DEXT;
using gl::glTexSubImage4DSGIS;
using gl::glTextureAttachMemoryNV;
using gl::glTextureBarrier;
using gl::glTextureBarrierNV;
using gl::glTextureBuffer;
using gl::glTextureBufferEXT;
using gl::glTextureBufferRange;
using gl::glTextureBufferRangeEXT;
using gl::glTextureColorMaskSGIS;
using gl::glTextureImage1DEXT;
using gl::glTextureImage2DEXT;
using gl::glTextureImage2DMultisampleCoverageNV;
using gl::glTextureImage2DMultisampleNV;
using gl::glTextureImage3DEXT;
using gl::glTextureImage3DMultisampleCoverageNV;
using gl::glTextureImage3DMultisampleNV;
using gl::glTextureLightEXT;
using gl::glTextureMaterialEXT;
using gl::glTextureNormalEXT;
using gl::glTexturePageCommitmentEXT;
using gl::glTexturePageCommitmentMemNV;
using gl::glTextureParameterf;
using gl::glTextureParameterfEXT;
using gl::glTextureParameterfv;
using gl::glTextureParameterfvEXT;
using gl::glTextureParameteri;
using gl::glTextureParameteriEXT;
using gl::glTextureParameterIiv;
using gl::glTextureParameterIivEXT;
using gl::glTextureParameterIuiv;
using gl::glTextureParameterIuivEXT;
using gl::glTextureParameteriv;
using gl::glTextureParameterivEXT;
using gl::glTextureRangeAPPLE;
using gl::glTextureRenderbufferEXT;
using gl::glTextureStorage1D;
using gl::glTextureStorage1DEXT;
using gl::glTextureStorage2D;
using gl::glTextureStorage2DEXT;
using gl::glTextureStorage2DMultisample;
using gl::glTextureStorage2DMultisampleEXT;
using gl::glTextureStorage3D;
using gl::glTextureStorage3DEXT;
using gl::glTextureStorage3DMultisample;
using gl::glTextureStorage3DMultisampleEXT;
using gl::glTextureStorageMem1DEXT;
using gl::glTextureStorageMem2DEXT;
using gl::glTextureStorageMem2DMultisampleEXT;
using gl::glTextureStorageMem3DEXT;
using gl::glTextureStorageMem3DMultisampleEXT;
using gl::glTextureStorageSparseAMD;
using gl::glTextureSubImage1D;
using gl::glTextureSubImage1DEXT;
using gl::glTextureSubImage2D;
using gl::glTextureSubImage2DEXT;
using gl::glTextureSubImage3D;
using gl::glTextureSubImage3DEXT;
using gl::glTextureView;
using gl::glTrackMatrixNV;
using gl::glTransformFeedbackAttribsNV;
using gl::glTransformFeedbackBufferBase;
using gl::glTransformFeedbackBufferRange;
using gl::glTransformFeedbackStreamAttribsNV;
using gl::glTransformFeedbackVaryings;
using gl::glTransformFeedbackVaryingsEXT;
using gl::glTransformFeedbackVaryingsNV;
using gl::glTransformPathNV;
using gl::glTranslatexOES;
using gl::glUniform1d;
using gl::glUniform1dv;
using gl::glUniform1f;
using gl::glUniform1fARB;
using gl::glUniform1fv;
using gl::glUniform1fvARB;
using gl::glUniform1i;
using gl::glUniform1i64ARB;
using gl::glUniform1i64NV;
using gl::glUniform1i64vARB;
using gl::glUniform1i64vNV;
using gl::glUniform1iARB;
using gl::glUniform1iv;
using gl::glUniform1ivARB;
using gl::glUniform1ui;
using gl::glUniform1ui64ARB;
using gl::glUniform1ui64NV;
using gl::glUniform1ui64vARB;
using gl::glUniform1ui64vNV;
using gl::glUniform1uiEXT;
using gl::glUniform1uiv;
using gl::glUniform1uivEXT;
using gl::glUniform2d;
using gl::glUniform2dv;
using gl::glUniform2f;
using gl::glUniform2fARB;
using gl::glUniform2fv;
using gl::glUniform2fvARB;
using gl::glUniform2i;
using gl::glUniform2i64ARB;
using gl::glUniform2i64NV;
using gl::glUniform2i64vARB;
using gl::glUniform2i64vNV;
using gl::glUniform2iARB;
using gl::glUniform2iv;
using gl::glUniform2ivARB;
using gl::glUniform2ui;
using gl::glUniform2ui64ARB;
using gl::glUniform2ui64NV;
using gl::glUniform2ui64vARB;
using gl::glUniform2ui64vNV;
using gl::glUniform2uiEXT;
using gl::glUniform2uiv;
using gl::glUniform2uivEXT;
using gl::glUniform3d;
using gl::glUniform3dv;
using gl::glUniform3f;
using gl::glUniform3fARB;
using gl::glUniform3fv;
using gl::glUniform3fvARB;
using gl::glUniform3i;
using gl::glUniform3i64ARB;
using gl::glUniform3i64NV;
using gl::glUniform3i64vARB;
using gl::glUniform3i64vNV;
using gl::glUniform3iARB;
using gl::glUniform3iv;
using gl::glUniform3ivARB;
using gl::glUniform3ui;
using gl::glUniform3ui64ARB;
using gl::glUniform3ui64NV;
using gl::glUniform3ui64vARB;
using gl::glUniform3ui64vNV;
using gl::glUniform3uiEXT;
using gl::glUniform3uiv;
using gl::glUniform3uivEXT;
using gl::glUniform4d;
using gl::glUniform4dv;
using gl::glUniform4f;
using gl::glUniform4fARB;
using gl::glUniform4fv;
using gl::glUniform4fvARB;
using gl::glUniform4i;
using gl::glUniform4i64ARB;
using gl::glUniform4i64NV;
using gl::glUniform4i64vARB;
using gl::glUniform4i64vNV;
using gl::glUniform4iARB;
using gl::glUniform4iv;
using gl::glUniform4ivARB;
using gl::glUniform4ui;
using gl::glUniform4ui64ARB;
using gl::glUniform4ui64NV;
using gl::glUniform4ui64vARB;
using gl::glUniform4ui64vNV;
using gl::glUniform4uiEXT;
using gl::glUniform4uiv;
using gl::glUniform4uivEXT;
using gl::glUniformBlockBinding;
using gl::glUniformBufferEXT;
using gl::glUniformHandleui64ARB;
using gl::glUniformHandleui64NV;
using gl::glUniformHandleui64vARB;
using gl::glUniformHandleui64vNV;
using gl::glUniformMatrix2dv;
using gl::glUniformMatrix2fv;
using gl::glUniformMatrix2fvARB;
using gl::glUniformMatrix2x3dv;
using gl::glUniformMatrix2x3fv;
using gl::glUniformMatrix2x4dv;
using gl::glUniformMatrix2x4fv;
using gl::glUniformMatrix3dv;
using gl::glUniformMatrix3fv;
using gl::glUniformMatrix3fvARB;
using gl::glUniformMatrix3x2dv;
using gl::glUniformMatrix3x2fv;
using gl::glUniformMatrix3x4dv;
using gl::glUniformMatrix3x4fv;
using gl::glUniformMatrix4dv;
using gl::glUniformMatrix4fv;
using gl::glUniformMatrix4fvARB;
using gl::glUniformMatrix4x2dv;
using gl::glUniformMatrix4x2fv;
using gl::glUniformMatrix4x3dv;
using gl::glUniformMatrix4x3fv;
using gl::glUniformSubroutinesuiv;
using gl::glUniformui64NV;
using gl::glUniformui64vNV;
using gl::glUnlockArraysEXT;
using gl::glUnmapBufferARB;
using gl::glUnmapNamedBuffer;
using gl::glUnmapNamedBufferEXT;
using gl::glUnmapObjectBufferATI;
using gl::glUnmapTexture2DINTEL;
using gl::glUpdateObjectBufferATI;
using gl::glUploadGpuMaskNVX;
using gl::glUseProgram;
using gl::glUseProgramObjectARB;
using gl::glUseProgramStages;
using gl::glUseProgramStagesEXT;
using gl::glUseShaderProgramEXT;
using gl::glValidateProgram;
using gl::glValidateProgramARB;
using gl::glValidateProgramPipeline;
using gl::glValidateProgramPipelineEXT;
using gl::glVariantArrayObjectATI;
using gl::glVariantbvEXT;
using gl::glVariantdvEXT;
using gl::glVariantfvEXT;
using gl::glVariantivEXT;
using gl::glVariantPointerEXT;
using gl::glVariantsvEXT;
using gl::glVariantubvEXT;
using gl::glVariantuivEXT;
using gl::glVariantusvEXT;
using gl::glVDPAUFiniNV;
using gl::glVDPAUGetSurfaceivNV;
using gl::glVDPAUInitNV;
using gl::glVDPAUIsSurfaceNV;
using gl::glVDPAUMapSurfacesNV;
using gl::glVDPAURegisterOutputSurfaceNV;
using gl::glVDPAURegisterVideoSurfaceNV;
using gl::glVDPAURegisterVideoSurfaceWithPictureStructureNV;
using gl::glVDPAUSurfaceAccessNV;
using gl::glVDPAUUnmapSurfacesNV;
using gl::glVDPAUUnregisterSurfaceNV;
using gl::glVertex2bOES;
using gl::glVertex2bvOES;
using gl::glVertex2hNV;
using gl::glVertex2hvNV;
using gl::glVertex2xOES;
using gl::glVertex2xvOES;
using gl::glVertex3bOES;
using gl::glVertex3bvOES;
using gl::glVertex3hNV;
using gl::glVertex3hvNV;
using gl::glVertex3xOES;
using gl::glVertex3xvOES;
using gl::glVertex4bOES;
using gl::glVertex4bvOES;
using gl::glVertex4hNV;
using gl::glVertex4hvNV;
using gl::glVertex4xOES;
using gl::glVertex4xvOES;
using gl::glVertexArrayAttribBinding;
using gl::glVertexArrayAttribFormat;
using gl::glVertexArrayAttribIFormat;
using gl::glVertexArrayAttribLFormat;
using gl::glVertexArrayBindingDivisor;
using gl::glVertexArrayBindVertexBufferEXT;
using gl::glVertexArrayColorOffsetEXT;
using gl::glVertexArrayEdgeFlagOffsetEXT;
using gl::glVertexArrayElementBuffer;
using gl::glVertexArrayFogCoordOffsetEXT;
using gl::glVertexArrayIndexOffsetEXT;
using gl::glVertexArrayMultiTexCoordOffsetEXT;
using gl::glVertexArrayNormalOffsetEXT;
using gl::glVertexArrayParameteriAPPLE;
using gl::glVertexArrayRangeAPPLE;
using gl::glVertexArrayRangeNV;
using gl::glVertexArraySecondaryColorOffsetEXT;
using gl::glVertexArrayTexCoordOffsetEXT;
using gl::glVertexArrayVertexAttribBindingEXT;
using gl::glVertexArrayVertexAttribDivisorEXT;
using gl::glVertexArrayVertexAttribFormatEXT;
using gl::glVertexArrayVertexAttribIFormatEXT;
using gl::glVertexArrayVertexAttribIOffsetEXT;
using gl::glVertexArrayVertexAttribLFormatEXT;
using gl::glVertexArrayVertexAttribLOffsetEXT;
using gl::glVertexArrayVertexAttribOffsetEXT;
using gl::glVertexArrayVertexBindingDivisorEXT;
using gl::glVertexArrayVertexBuffer;
using gl::glVertexArrayVertexBuffers;
using gl::glVertexArrayVertexOffsetEXT;
using gl::glVertexAttrib1d;
using gl::glVertexAttrib1dARB;
using gl::glVertexAttrib1dNV;
using gl::glVertexAttrib1dv;
using gl::glVertexAttrib1dvARB;
using gl::glVertexAttrib1dvNV;
using gl::glVertexAttrib1f;
using gl::glVertexAttrib1fARB;
using gl::glVertexAttrib1fNV;
using gl::glVertexAttrib1fv;
using gl::glVertexAttrib1fvARB;
using gl::glVertexAttrib1fvNV;
using gl::glVertexAttrib1hNV;
using gl::glVertexAttrib1hvNV;
using gl::glVertexAttrib1s;
using gl::glVertexAttrib1sARB;
using gl::glVertexAttrib1sNV;
using gl::glVertexAttrib1sv;
using gl::glVertexAttrib1svARB;
using gl::glVertexAttrib1svNV;
using gl::glVertexAttrib2d;
using gl::glVertexAttrib2dARB;
using gl::glVertexAttrib2dNV;
using gl::glVertexAttrib2dv;
using gl::glVertexAttrib2dvARB;
using gl::glVertexAttrib2dvNV;
using gl::glVertexAttrib2f;
using gl::glVertexAttrib2fARB;
using gl::glVertexAttrib2fNV;
using gl::glVertexAttrib2fv;
using gl::glVertexAttrib2fvARB;
using gl::glVertexAttrib2fvNV;
using gl::glVertexAttrib2hNV;
using gl::glVertexAttrib2hvNV;
using gl::glVertexAttrib2s;
using gl::glVertexAttrib2sARB;
using gl::glVertexAttrib2sNV;
using gl::glVertexAttrib2sv;
using gl::glVertexAttrib2svARB;
using gl::glVertexAttrib2svNV;
using gl::glVertexAttrib3d;
using gl::glVertexAttrib3dARB;
using gl::glVertexAttrib3dNV;
using gl::glVertexAttrib3dv;
using gl::glVertexAttrib3dvARB;
using gl::glVertexAttrib3dvNV;
using gl::glVertexAttrib3f;
using gl::glVertexAttrib3fARB;
using gl::glVertexAttrib3fNV;
using gl::glVertexAttrib3fv;
using gl::glVertexAttrib3fvARB;
using gl::glVertexAttrib3fvNV;
using gl::glVertexAttrib3hNV;
using gl::glVertexAttrib3hvNV;
using gl::glVertexAttrib3s;
using gl::glVertexAttrib3sARB;
using gl::glVertexAttrib3sNV;
using gl::glVertexAttrib3sv;
using gl::glVertexAttrib3svARB;
using gl::glVertexAttrib3svNV;
using gl::glVertexAttrib4bv;
using gl::glVertexAttrib4bvARB;
using gl::glVertexAttrib4d;
using gl::glVertexAttrib4dARB;
using gl::glVertexAttrib4dNV;
using gl::glVertexAttrib4dv;
using gl::glVertexAttrib4dvARB;
using gl::glVertexAttrib4dvNV;
using gl::glVertexAttrib4f;
using gl::glVertexAttrib4fARB;
using gl::glVertexAttrib4fNV;
using gl::glVertexAttrib4fv;
using gl::glVertexAttrib4fvARB;
using gl::glVertexAttrib4fvNV;
using gl::glVertexAttrib4hNV;
using gl::glVertexAttrib4hvNV;
using gl::glVertexAttrib4iv;
using gl::glVertexAttrib4ivARB;
using gl::glVertexAttrib4Nbv;
using gl::glVertexAttrib4NbvARB;
using gl::glVertexAttrib4Niv;
using gl::glVertexAttrib4NivARB;
using gl::glVertexAttrib4Nsv;
using gl::glVertexAttrib4NsvARB;
using gl::glVertexAttrib4Nub;
using gl::glVertexAttrib4NubARB;
using gl::glVertexAttrib4Nubv;
using gl::glVertexAttrib4NubvARB;
using gl::glVertexAttrib4Nuiv;
using gl::glVertexAttrib4NuivARB;
using gl::glVertexAttrib4Nusv;
using gl::glVertexAttrib4NusvARB;
using gl::glVertexAttrib4s;
using gl::glVertexAttrib4sARB;
using gl::glVertexAttrib4sNV;
using gl::glVertexAttrib4sv;
using gl::glVertexAttrib4svARB;
using gl::glVertexAttrib4svNV;
using gl::glVertexAttrib4ubNV;
using gl::glVertexAttrib4ubv;
using gl::glVertexAttrib4ubvARB;
using gl::glVertexAttrib4ubvNV;
using gl::glVertexAttrib4uiv;
using gl::glVertexAttrib4uivARB;
using gl::glVertexAttrib4usv;
using gl::glVertexAttrib4usvARB;
using gl::glVertexAttribArrayObjectATI;
using gl::glVertexAttribBinding;
using gl::glVertexAttribDivisor;
using gl::glVertexAttribDivisorARB;
using gl::glVertexAttribFormat;
using gl::glVertexAttribFormatNV;
using gl::glVertexAttribI1i;
using gl::glVertexAttribI1iEXT;
using gl::glVertexAttribI1iv;
using gl::glVertexAttribI1ivEXT;
using gl::glVertexAttribI1ui;
using gl::glVertexAttribI1uiEXT;
using gl::glVertexAttribI1uiv;
using gl::glVertexAttribI1uivEXT;
using gl::glVertexAttribI2i;
using gl::glVertexAttribI2iEXT;
using gl::glVertexAttribI2iv;
using gl::glVertexAttribI2ivEXT;
using gl::glVertexAttribI2ui;
using gl::glVertexAttribI2uiEXT;
using gl::glVertexAttribI2uiv;
using gl::glVertexAttribI2uivEXT;
using gl::glVertexAttribI3i;
using gl::glVertexAttribI3iEXT;
using gl::glVertexAttribI3iv;
using gl::glVertexAttribI3ivEXT;
using gl::glVertexAttribI3ui;
using gl::glVertexAttribI3uiEXT;
using gl::glVertexAttribI3uiv;
using gl::glVertexAttribI3uivEXT;
using gl::glVertexAttribI4bv;
using gl::glVertexAttribI4bvEXT;
using gl::glVertexAttribI4i;
using gl::glVertexAttribI4iEXT;
using gl::glVertexAttribI4iv;
using gl::glVertexAttribI4ivEXT;
using gl::glVertexAttribI4sv;
using gl::glVertexAttribI4svEXT;
using gl::glVertexAttribI4ubv;
using gl::glVertexAttribI4ubvEXT;
using gl::glVertexAttribI4ui;
using gl::glVertexAttribI4uiEXT;
using gl::glVertexAttribI4uiv;
using gl::glVertexAttribI4uivEXT;
using gl::glVertexAttribI4usv;
using gl::glVertexAttribI4usvEXT;
using gl::glVertexAttribIFormat;
using gl::glVertexAttribIFormatNV;
using gl::glVertexAttribIPointer;
using gl::glVertexAttribIPointerEXT;
using gl::glVertexAttribL1d;
using gl::glVertexAttribL1dEXT;
using gl::glVertexAttribL1dv;
using gl::glVertexAttribL1dvEXT;
using gl::glVertexAttribL1i64NV;
using gl::glVertexAttribL1i64vNV;
using gl::glVertexAttribL1ui64ARB;
using gl::glVertexAttribL1ui64NV;
using gl::glVertexAttribL1ui64vARB;
using gl::glVertexAttribL1ui64vNV;
using gl::glVertexAttribL2d;
using gl::glVertexAttribL2dEXT;
using gl::glVertexAttribL2dv;
using gl::glVertexAttribL2dvEXT;
using gl::glVertexAttribL2i64NV;
using gl::glVertexAttribL2i64vNV;
using gl::glVertexAttribL2ui64NV;
using gl::glVertexAttribL2ui64vNV;
using gl::glVertexAttribL3d;
using gl::glVertexAttribL3dEXT;
using gl::glVertexAttribL3dv;
using gl::glVertexAttribL3dvEXT;
using gl::glVertexAttribL3i64NV;
using gl::glVertexAttribL3i64vNV;
using gl::glVertexAttribL3ui64NV;
using gl::glVertexAttribL3ui64vNV;
using gl::glVertexAttribL4d;
using gl::glVertexAttribL4dEXT;
using gl::glVertexAttribL4dv;
using gl::glVertexAttribL4dvEXT;
using gl::glVertexAttribL4i64NV;
using gl::glVertexAttribL4i64vNV;
using gl::glVertexAttribL4ui64NV;
using gl::glVertexAttribL4ui64vNV;
using gl::glVertexAttribLFormat;
using gl::glVertexAttribLFormatNV;
using gl::glVertexAttribLPointer;
using gl::glVertexAttribLPointerEXT;
using gl::glVertexAttribP1ui;
using gl::glVertexAttribP1uiv;
using gl::glVertexAttribP2ui;
using gl::glVertexAttribP2uiv;
using gl::glVertexAttribP3ui;
using gl::glVertexAttribP3uiv;
using gl::glVertexAttribP4ui;
using gl::glVertexAttribP4uiv;
using gl::glVertexAttribParameteriAMD;
using gl::glVertexAttribPointer;
using gl::glVertexAttribPointerARB;
using gl::glVertexAttribPointerNV;
using gl::glVertexAttribs1dvNV;
using gl::glVertexAttribs1fvNV;
using gl::glVertexAttribs1hvNV;
using gl::glVertexAttribs1svNV;
using gl::glVertexAttribs2dvNV;
using gl::glVertexAttribs2fvNV;
using gl::glVertexAttribs2hvNV;
using gl::glVertexAttribs2svNV;
using gl::glVertexAttribs3dvNV;
using gl::glVertexAttribs3fvNV;
using gl::glVertexAttribs3hvNV;
using gl::glVertexAttribs3svNV;
using gl::glVertexAttribs4dvNV;
using gl::glVertexAttribs4fvNV;
using gl::glVertexAttribs4hvNV;
using gl::glVertexAttribs4svNV;
using gl::glVertexAttribs4ubvNV;
using gl::glVertexBindingDivisor;
using gl::glVertexBlendARB;
using gl::glVertexBlendEnvfATI;
using gl::glVertexBlendEnviATI;
using gl::glVertexFormatNV;
using gl::glVertexP2ui;
using gl::glVertexP2uiv;
using gl::glVertexP3ui;
using gl::glVertexP3uiv;
using gl::glVertexP4ui;
using gl::glVertexP4uiv;
using gl::glVertexPointerEXT;
using gl::glVertexPointerListIBM;
using gl::glVertexPointervINTEL;
using gl::glVertexStream1dATI;
using gl::glVertexStream1dvATI;
using gl::glVertexStream1fATI;
using gl::glVertexStream1fvATI;
using gl::glVertexStream1iATI;
using gl::glVertexStream1ivATI;
using gl::glVertexStream1sATI;
using gl::glVertexStream1svATI;
using gl::glVertexStream2dATI;
using gl::glVertexStream2dvATI;
using gl::glVertexStream2fATI;
using gl::glVertexStream2fvATI;
using gl::glVertexStream2iATI;
using gl::glVertexStream2ivATI;
using gl::glVertexStream2sATI;
using gl::glVertexStream2svATI;
using gl::glVertexStream3dATI;
using gl::glVertexStream3dvATI;
using gl::glVertexStream3fATI;
using gl::glVertexStream3fvATI;
using gl::glVertexStream3iATI;
using gl::glVertexStream3ivATI;
using gl::glVertexStream3sATI;
using gl::glVertexStream3svATI;
using gl::glVertexStream4dATI;
using gl::glVertexStream4dvATI;
using gl::glVertexStream4fATI;
using gl::glVertexStream4fvATI;
using gl::glVertexStream4iATI;
using gl::glVertexStream4ivATI;
using gl::glVertexStream4sATI;
using gl::glVertexStream4svATI;
using gl::glVertexWeightfEXT;
using gl::glVertexWeightfvEXT;
using gl::glVertexWeighthNV;
using gl::glVertexWeighthvNV;
using gl::glVertexWeightPointerEXT;
using gl::glVideoCaptureNV;
using gl::glVideoCaptureStreamParameterdvNV;
using gl::glVideoCaptureStreamParameterfvNV;
using gl::glVideoCaptureStreamParameterivNV;
using gl::glViewportArrayv;
using gl::glViewportIndexedf;
using gl::glViewportIndexedfv;
using gl::glViewportPositionWScaleNV;
using gl::glViewportSwizzleNV;
using gl::glWaitSemaphoreEXT;
using gl::glWaitSemaphoreui64NVX;
using gl::glWaitSync;
using gl::glWaitVkSemaphoreNV;
using gl::glWeightbvARB;
using gl::glWeightdvARB;
using gl::glWeightfvARB;
using gl::glWeightivARB;
using gl::glWeightPathsNV;
using gl::glWeightPointerARB;
using gl::glWeightsvARB;
using gl::glWeightubvARB;
using gl::glWeightuivARB;
using gl::glWeightusvARB;
using gl::glWindowPos2dARB;
using gl::glWindowPos2dMESA;
using gl::glWindowPos2dvARB;
using gl::glWindowPos2dvMESA;
using gl::glWindowPos2fARB;
using gl::glWindowPos2fMESA;
using gl::glWindowPos2fvARB;
using gl::glWindowPos2fvMESA;
using gl::glWindowPos2iARB;
using gl::glWindowPos2iMESA;
using gl::glWindowPos2ivARB;
using gl::glWindowPos2ivMESA;
using gl::glWindowPos2sARB;
using gl::glWindowPos2sMESA;
using gl::glWindowPos2svARB;
using gl::glWindowPos2svMESA;
using gl::glWindowPos3dARB;
using gl::glWindowPos3dMESA;
using gl::glWindowPos3dvARB;
using gl::glWindowPos3dvMESA;
using gl::glWindowPos3fARB;
using gl::glWindowPos3fMESA;
using gl::glWindowPos3fvARB;
using gl::glWindowPos3fvMESA;
using gl::glWindowPos3iARB;
using gl::glWindowPos3iMESA;
using gl::glWindowPos3ivARB;
using gl::glWindowPos3ivMESA;
using gl::glWindowPos3sARB;
using gl::glWindowPos3sMESA;
using gl::glWindowPos3svARB;
using gl::glWindowPos3svMESA;
using gl::glWindowPos4dMESA;
using gl::glWindowPos4dvMESA;
using gl::glWindowPos4fMESA;
using gl::glWindowPos4fvMESA;
using gl::glWindowPos4iMESA;
using gl::glWindowPos4ivMESA;
using gl::glWindowPos4sMESA;
using gl::glWindowPos4svMESA;
using gl::glWindowRectanglesEXT;
using gl::glWriteMaskEXT;

} // namespace gl15ext